@@ -32,14 +32,65 @@
 #include "controls.h"
 #include "fileselection.h"
 #include "utilities.h"
-#include "support.h"
+#include "resources.h"
 #include "messagebox.h"
 #include "launcher.h"
 #include "debugger.h"
 
-/* Blurp ?? */
+/* Blurb ?? */
 extern gboolean closing_state;
 
+gint
+on_anjuta_session_die(GnomeClient * client, gpointer data)
+{
+	gtk_main_quit();
+	return FALSE;
+}
+
+/* Saves the current anjuta session */
+gint on_anjuta_session_save_yourself (GnomeClient * client, gint phase,
+		       GnomeSaveStyle s_style, gint shutdown,
+		       GnomeInteractStyle i_style, gint fast, gpointer data)
+{
+	gchar *argv[] = { "rm",	"-rf", NULL};
+	gchar *prefix, **res_argv;
+	gint res_argc, counter;
+	GList* node;
+
+	prefix = gnome_client_get_config_prefix (client);
+	argv[2] = gnome_config_get_real_path (prefix);
+	gnome_client_set_discard_command (client, 3, argv);
+
+	res_argc = g_list_length (app->text_editor_list) + 1;
+	if (app->project_dbase->project_is_open)
+		res_argc++;
+	res_argv = g_malloc (res_argc * sizeof (char*));
+	res_argv[0] = data;
+	counter = 1;
+	if (app->project_dbase->project_is_open)
+	{
+		res_argv[counter] = app->project_dbase->proj_filename;
+		counter++;
+	}
+	node = app->text_editor_list;
+	while (node)
+	{
+		TextEditor* te;
+		
+		te = node->data;
+		if (te->full_filename)
+		{
+			res_argv[counter] = te->full_filename;
+			counter++;
+		}
+		node = g_list_next (node);
+	}
+	gnome_client_set_restart_command(client, res_argc, res_argv);
+	g_free (res_argv);
+	anjuta_save_settings ();	
+	return TRUE;
+}
+
 gint on_anjuta_delete (GtkWidget * w, GdkEvent * event, gpointer data)
 {
 	TextEditor *te;
@@ -99,7 +150,7 @@ on_anjuta_exit_yes_clicked (GtkButton * b, gpointer data)
 void
 on_anjuta_destroy (GtkWidget * w, gpointer data)
 {
-
+	/* Nothing to be done here */
 }
 
 void
@@ -116,23 +167,29 @@ void
 on_open_filesel_ok_clicked (GtkButton * button, gpointer user_data)
 {
 	gchar *full_filename;
-	full_filename =
-		gtk_file_selection_get_filename (GTK_FILE_SELECTION
-						 (app->fileselection));
-	if (strlen (extract_filename (full_filename)) == 0)
+	full_filename = fileselection_get_filename (app->fileselection);
+	if (!full_filename)
 		return;
+	if (strlen (extract_filename (full_filename)) == 0)
+	{
+		g_free (full_filename);
+		return;
+	}
 	if (file_is_regular (full_filename) == FALSE)
 	{
 		anjuta_error (_("Not a regular file: %s."), full_filename);
+		g_free (full_filename);
 		return;
 	}
 	if (file_is_readable (full_filename) == FALSE)
 	{
 		anjuta_error (_("No read permission for: %s."), full_filename);
+		g_free (full_filename);
 		return;
 	}
 	anjuta_goto_file_line (full_filename, -1);
 	gtk_widget_hide (app->fileselection);
+	g_free (full_filename);
 }
 
 void
@@ -146,15 +203,12 @@ on_save_as_filesel_ok_clicked (GtkButton * button, gpointer user_data)
 {
 	gchar *filename, *buff;
 
-	filename =
-		gtk_file_selection_get_filename (GTK_FILE_SELECTION
-						 (app->
-						  save_as_fileselection));
+	filename = fileselection_get_filename (app->save_as_fileselection);
 	if (file_is_regular (filename))
 	{
 		buff =
 			g_strdup_printf (_
-					 ("The file \"%s\" already exist.\nDo you want to overwrite it?."),
+					 ("The file \"%s\" already exists.\nDo you want to overwrite it?."),
 					 filename);
 		messagebox2 (GNOME_MESSAGE_BOX_QUESTION, buff,
 			     GNOME_STOCK_BUTTON_YES, GNOME_STOCK_BUTTON_NO,
@@ -165,6 +219,7 @@ on_save_as_filesel_ok_clicked (GtkButton * button, gpointer user_data)
 	}
 	else
 		on_save_as_overwrite_yes_clicked (NULL, user_data);
+	g_free (filename);
 }
 
 void
@@ -175,11 +230,11 @@ on_save_as_overwrite_yes_clicked (GtkButton * button, gpointer user_data)
 	gint page_num;
 	GtkWidget *child;
 
+	full_filename = fileselection_get_filename (app->save_as_fileselection);
+	if (!full_filename)
+		return;
+
 	te = anjuta_get_current_text_editor ();
-	full_filename =
-		gtk_file_selection_get_filename (GTK_FILE_SELECTION
-						 (app->
-						  save_as_fileselection));
 	g_return_if_fail (te != NULL);
 	g_return_if_fail (strlen (extract_filename (full_filename)) != 0);
 
@@ -224,6 +279,7 @@ on_save_as_overwrite_yes_clicked (GtkButton * button, gpointer user_data)
 		}
 	}
 	anjuta_update_title ();
+	g_free (full_filename);
 }
 
 gboolean
