@@ -48,9 +48,11 @@ prog_language_map[]=
 	"Java", "java",
 	"Perl", "perl",
 	"Python", "py",
+	"Pascal", "pascal",
+	"Ada", "ada",
 	"Lua", "lua",
 	"LaTex", "latex",
-	NULL
+	NULL, NULL
 };
 
 /* Command data to be used in command editor */
@@ -261,6 +263,10 @@ command_editor_save (CommandEditor *ce, FILE* s)
 			if (fprintf (s, "%s=%s\n", key, str) < 2) return FALSE;
 			string_free (str);
 		}
+		else
+		{
+			if (fprintf (s, "%s=\n", key) < 1) return FALSE;
+		}
 		g_free (key);
 		
 		key = get_key_for_file_command (BUILD_INDEX, prog_language_map[i+1]);
@@ -270,6 +276,10 @@ command_editor_save (CommandEditor *ce, FILE* s)
 			if (fprintf (s, "%s=%s\n", key, str) < 2) return FALSE;
 			string_free (str);
 		}
+		else
+		{
+			if (fprintf (s, "%s=\n", key) < 1) return FALSE;
+		}
 		g_free (key);
 		
 		key = get_key_for_file_command (EXECUTE_INDEX, prog_language_map[i+1]);
@@ -279,6 +289,10 @@ command_editor_save (CommandEditor *ce, FILE* s)
 			if (fprintf (s, "%s=%s\n", key, str) < 2) return FALSE;
 			string_free (str);
 		}
+		else
+		{
+			if (fprintf (s, "%s=\n", key) < 1) return FALSE;
+		}
 		g_free (key);
 	}
 
@@ -289,6 +303,10 @@ command_editor_save (CommandEditor *ce, FILE* s)
 		if (fprintf (s, "%s=%s\n", key, str) < 2) return FALSE;
 		string_free (str);
 	}
+	else
+	{
+		if (fprintf (s, "%s=\n", key) < 1) return FALSE;
+	}
 	g_free (key);
 
 	key = get_key_for_file_command (OPEN_INDEX, "image");
@@ -298,6 +316,10 @@ command_editor_save (CommandEditor *ce, FILE* s)
 		if (fprintf (s, "%s=%s\n", key, str) < 2) return FALSE;
 		string_free (str);
 	}
+	else
+	{
+		if (fprintf (s, "%s=\n", key) < 1) return FALSE;
+	}
 	g_free (key);
 
 	key = get_key_for_file_command (VIEW_INDEX, "html");
@@ -307,6 +329,10 @@ command_editor_save (CommandEditor *ce, FILE* s)
 		if (fprintf (s, "%s=%s\n", key, str) < 2) return FALSE;
 		string_free (str);
 	}
+	else
+	{
+		if (fprintf (s, "%s=\n", key) < 1) return FALSE;
+	}
 	g_free (key);
 	
 	return TRUE;
@@ -513,7 +539,10 @@ create_command_editor_gui (CommandEditor *ce)
 	GList* list = NULL;
 	gint i;
 	
-	dialog1 = gnome_dialog_new (NULL, NULL);
+	dialog1 = gnome_dialog_new (_("Commands"), NULL);
+	gtk_window_set_policy (GTK_WINDOW (dialog1), FALSE, FALSE, FALSE);
+	gtk_window_set_wmclass (GTK_WINDOW (dialog1), "commands", "Anjuta");
+	gnome_dialog_close_hides (GNOME_DIALOG (dialog1), TRUE);
 	
 	dialog_vbox1 = GNOME_DIALOG (dialog1)->vbox;
 	gtk_widget_show (dialog_vbox1);
@@ -640,7 +669,7 @@ create_command_editor_gui (CommandEditor *ce)
 	gtk_widget_set_usize (label6, 120, -2);
 	gtk_misc_set_alignment (GTK_MISC (label6), 0, -1);
 
-	label7 = gtk_label_new (_("Html viewer:"));
+	label7 = gtk_label_new (_("HTML viewer:"));
 	gtk_widget_show (label7);
 	gtk_table_attach (GTK_TABLE (table4), label7, 0, 1, 2, 3,
 		    (GtkAttachOptions) (0),
