@@ -31,7 +31,7 @@
 #include "messagebox.h"
 #include "utilities.h"
 #include "executer.h"
-#include "support.h"
+#include "resources.h"
 
 static GtkWidget* create_executer_dialog(Executer*);
 
@@ -67,7 +67,7 @@ executer_show (Executer * e)
 	gtk_widget_show (create_executer_dialog (e));
 }
 
-GtkWidget *
+static GtkWidget *
 create_executer_dialog (Executer * e)
 {
 	GtkWidget *dialog1;
@@ -85,6 +85,7 @@ create_executer_dialog (Executer * e)
 	dialog1 = gnome_dialog_new (_("Execute"), NULL);
 	gtk_window_set_position (GTK_WINDOW (dialog1), GTK_WIN_POS_CENTER);
 	gtk_window_set_policy (GTK_WINDOW (dialog1), FALSE, FALSE, FALSE);
+	gtk_window_set_wmclass (GTK_WINDOW (dialog1), "exec", "Anjuta");
 	gtk_widget_set_usize (dialog1, 400, -2);
 	gnome_dialog_set_close (GNOME_DIALOG (dialog1), TRUE);
 
@@ -154,7 +155,7 @@ create_executer_dialog (Executer * e)
 }
 
 
-void
+static void
 on_executer_entry_changed (GtkEditable * editable, gpointer user_data)
 {
 	Executer *e = user_data;
@@ -166,7 +167,7 @@ on_executer_entry_changed (GtkEditable * editable, gpointer user_data)
 		prop_set_with_key (e->props, EXECUTER_PROGRAM_ARGS_KEY, "");
 }
 
-void
+static void
 on_executer_checkbutton_toggled (GtkToggleButton * togglebutton,
 				 gpointer user_data)
 {
@@ -203,15 +204,12 @@ executer_execute (Executer * e)
 			string_free (prog);
 			return;
 		}
+		string_free (prog);
 	}
 	else  /* File mode checks */
 	{
-		gchar *prog, *temp;
-		gint s_re, e_re;
-		struct stat s_stat, e_stat;
 		TextEditor *te;
 
-		prog = NULL;
 		te = anjuta_get_current_text_editor ();
 		if (!te)
 		{
@@ -223,23 +221,31 @@ executer_execute (Executer * e)
 			anjuta_warning(_("No executable for this file."));
 			return;
 		}
-		prog = g_strdup (te->full_filename);
-		temp = get_file_extension (prog);
-		if (temp)
-			*(--temp) = '\0';
-		s_re = stat (te->full_filename, &s_stat);
-		e_re = stat (prog, &e_stat);
-		if ((e_re != 0) || (s_re != 0))
+		if (anjuta_get_file_property (FILE_PROP_IS_INTERPRETED, te->full_filename, 0) == 0)
 		{
-			anjuta_warning(_("No executable for this file."));
+			gchar *prog, *temp;
+			gint s_re, e_re;
+			struct stat s_stat, e_stat;
+
+			prog = NULL;
+			prog = g_strdup (te->full_filename);
+			temp = get_file_extension (prog);
+			if (temp)
+				*(--temp) = '\0';
+			s_re = stat (te->full_filename, &s_stat);
+			e_re = stat (prog, &e_stat);
 			string_free (prog);
-			return;
-		}
-		else if ((!text_editor_is_saved (te)) || (e_stat.st_mtime < s_stat.st_mtime))
-		{
-			anjuta_warning (_("Executable is not up-to-date."));
-			/* But continue execution */
-		}
+			if ((e_re != 0) || (s_re != 0))
+			{
+				anjuta_warning(_("No executable for this file."));
+				return;
+			}
+			else if ((!text_editor_is_saved (te)) || (e_stat.st_mtime < s_stat.st_mtime))
+			{
+				anjuta_warning (_("Executable is not up-to-date."));
+				/* But continue execution */
+			}
+		} /* else continue execution */
 	}
 
 	if (app->project_dbase->project_is_open)  /* Execute project */
