@@ -16,6 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -26,17 +27,10 @@
 
 #include <gnome.h>
 #include "anjuta.h"
-#include "support.h"
+#include "resources.h"
 #include "fileselection.h"
 #include "utilities.h"
-
-/*
-static gchar filter_words[][20] = 
-{
-	"header", "cpp", "java", "js", "idl", "conf", "web", "php", "lua", "perl",
-	"python","properties", "project", "text", "diff", "icon", "image", "all"
-};
-*/
+#include "gnomefilelist.h"
 
 static gboolean
 on_fileselection_delete_event (GtkWidget * w, GdkEvent * event, gpointer data)
@@ -45,38 +39,26 @@ on_fileselection_delete_event (GtkWidget * w, GdkEvent * event, gpointer data)
 	return TRUE;
 }
 
-static void
-on_fileselection_home_button_clicked (GtkButton * button, gpointer data)
-{
-	FileSelData *fd = data;
-	gchar *home;
-	home = gnome_util_user_home ();
-	gtk_file_selection_complete (GTK_FILE_SELECTION (fd->filesel), home);
-}
-
-static void
-on_fileselection_filter_changed (GtkButton * button, gpointer data)
-{
-}
-
 static void
 on_file_selection_ok_clicked (GtkButton * button, gpointer data)
 {
 	gchar *filename;
 	FileSelData *fd = data;
 
-	filename =
-		gtk_file_selection_get_filename (GTK_FILE_SELECTION
-						 (fd->filesel));
+	filename = fileselection_get_filename (fd->filesel);
+	if (!filename)
+		return;
 	if (file_is_directory (filename))
 	{
-		gtk_file_selection_complete (GTK_FILE_SELECTION (fd->filesel),
-					     filename);
+		fileselection_set_dir (fd->filesel, filename);
+		g_free (filename);
 		return;
 	}
 	gtk_widget_hide (fd->filesel);
 	if (fd->click_ok_callback)
 		fd->click_ok_callback (button, fd->data);
+	
+	g_free (filename);
 	return;
 }
 
@@ -86,60 +68,27 @@ create_fileselection_gui (FileSelData * fsd)
 	GtkWidget *fileselection_gui;
 	GtkWidget *fileselection_ok;
 	GtkWidget *fileselection_cancel;
-	GtkWidget *label1;
-	GtkWidget *combo1;
-	GtkWidget *combo_entry1;
-	GtkWidget *vbox1;
-	GtkWidget *button1;
 
-	fileselection_gui = gtk_file_selection_new (_(fsd->title));
-	gtk_container_set_border_width (GTK_CONTAINER (fileselection_gui),
-					10);
-	gtk_window_set_position (GTK_WINDOW (fileselection_gui),
-				 GTK_WIN_POS_CENTER);
-	fileselection_ok = GTK_FILE_SELECTION (fileselection_gui)->ok_button;
+	fileselection_gui = gnome_filelist_new ();
+	gnome_filelist_set_title (GNOME_FILELIST(fileselection_gui), _(fsd->title));
+	gtk_container_set_border_width (GTK_CONTAINER (fileselection_gui), 10);
+	gtk_window_set_position (GTK_WINDOW (fileselection_gui), GTK_WIN_POS_CENTER);
+	gtk_window_set_wmclass (GTK_WINDOW (fileselection_gui), "filesel", "Anjuta");
+	
+	fileselection_ok = GNOME_FILELIST (fileselection_gui)->ok_button;
 	gtk_widget_show (fileselection_ok);
 	GTK_WIDGET_SET_FLAGS (fileselection_ok, GTK_CAN_DEFAULT);
 
-	fileselection_cancel =
-		GTK_FILE_SELECTION (fileselection_gui)->cancel_button;
+	fileselection_cancel =GNOME_FILELIST (fileselection_gui)->cancel_button;
 	gtk_widget_show (fileselection_cancel);
 	GTK_WIDGET_SET_FLAGS (fileselection_cancel, GTK_CAN_DEFAULT);
 
-	vbox1 = GTK_FILE_SELECTION (fileselection_gui)->main_vbox;
-
-	label1 = gtk_label_new (_("File type filter:"));
-	
-	/* Unimplemented */
-	/* gtk_widget_show (label1); */
-	gtk_misc_set_alignment (GTK_MISC (label1), 0, -1);
-	gtk_box_pack_start (GTK_BOX (vbox1), label1, TRUE, TRUE, 0);
-
-	combo1 = gtk_combo_new ();
-
-	/* Unimplemented */
-	/* gtk_widget_show (combo1);*/
-	gtk_box_pack_start (GTK_BOX (vbox1), combo1, TRUE, TRUE, 0);
-
-	combo_entry1 = GTK_COMBO (combo1)->entry;
-	vbox1 = GTK_FILE_SELECTION (fileselection_gui)->button_area;
-
-	button1 = gtk_button_new_with_label (_("Home"));
-	gtk_widget_show (button1);
-	gtk_box_pack_start (GTK_BOX (vbox1), button1, TRUE, TRUE, 0);
-
 	gtk_accel_group_attach (app->accel_group,
 				GTK_OBJECT (fileselection_gui));
 
 	gtk_signal_connect (GTK_OBJECT (fileselection_gui), "delete_event",
 			    GTK_SIGNAL_FUNC (on_fileselection_delete_event),
 			    fsd);
-	gtk_signal_connect (GTK_OBJECT (button1), "clicked",
-			    GTK_SIGNAL_FUNC
-			    (on_fileselection_home_button_clicked), fsd);
-	gtk_signal_connect (GTK_OBJECT (combo_entry1), "changed",
-			    GTK_SIGNAL_FUNC (on_fileselection_filter_changed),
-			    fsd);
 	gtk_signal_connect (GTK_OBJECT (fileselection_ok), "clicked",
 			    GTK_SIGNAL_FUNC (on_file_selection_ok_clicked),
 			    fsd);
@@ -154,17 +103,35 @@ create_fileselection_gui (FileSelData * fsd)
 	return fileselection_gui;
 }
 
-gchar *
-fileselection_get_filename (gchar * title, gchar * init_path, gchar * filter)
+
+/* Free the return */
+gchar*
+fileselection_get_filename (GtkWidget* filesel)
 {
-	GtkWidget *fs;
-	fs = gtk_file_selection_new (title);
-	if (init_path)
-	{
-		gtk_file_selection_set_filename (GTK_FILE_SELECTION (fs),
-						 init_path);
-		gtk_file_selection_complete (GTK_FILE_SELECTION (fs),
-					     init_path);
-	}
-	return NULL;
+	return gnome_filelist_get_filename (GNOME_FILELIST(filesel));
+}
+
+/* Free the return */
+gchar*
+fileselection_get_path (GtkWidget* filesel)
+{
+	return gnome_filelist_get_path (GNOME_FILELIST(filesel));
+}
+
+void
+fileselection_set_title (GtkWidget* filesel, gchar* title)
+{
+	return gnome_filelist_set_title (GNOME_FILELIST(filesel), title);
+}
+
+gboolean
+fileselection_set_dir (GtkWidget* filesel, gchar* dir)
+{
+	return gnome_filelist_set_dir (GNOME_FILELIST(filesel), dir);
+}
+
+gboolean
+fileselection_set_filename (GtkWidget* filesel, gchar* fname)
+{
+	return gnome_filelist_set_filename (GNOME_FILELIST(filesel), fname);
 }
