@@ -33,11 +33,21 @@ struct _FileSelData
   
 };
   
-GtkWidget*
-create_fileselection_gui (FileSelData *fd);
+GtkWidget* create_fileselection_gui (FileSelData *fd);
 
-gchar*
-fileselection_get_filename(gchar* title, gchar* init_path, gchar* filter);
+/* Free the return */
+gchar* fileselection_get_filename (GtkWidget* filesel);
+
+/* Free the return */
+gchar* fileselection_get_path (GtkWidget* filesel);
+
+void fileselection_set_title (GtkWidget* filesel, gchar* title);
+
+/* Sets the directory */
+gboolean fileselection_set_dir (GtkWidget* filesel, gchar* dir);
+
+/* Sets the filename path */
+gboolean
+fileselection_set_filename (GtkWidget* filesel, gchar* fname);
 
 #endif
-
