@@ -22,7 +22,7 @@
 
 #include <gnome.h>
 #include "anjuta.h"
-#include "support.h"
+#include "resources.h"
 #include "find_replace.h"
 
 #define GTK
@@ -243,7 +243,7 @@ find_replace_hide (FindAndReplace * fr)
 					       replace_prompt_check));
 }
 
-void
+static void
 create_find_replace_gui (FindAndReplace * fr)
 {
 	GtkWidget *dialog2;
@@ -280,14 +280,15 @@ create_find_replace_gui (FindAndReplace * fr)
 	GtkWidget *button10;
 	GtkWidget *button11;
 
-	dialog2 = gnome_dialog_new (NULL, NULL);
+	dialog2 = gnome_dialog_new (_("Find and Replace"), NULL);
 	gtk_window_set_policy (GTK_WINDOW (dialog2), FALSE, FALSE, FALSE);
+	gtk_window_set_wmclass (GTK_WINDOW (dialog2), "find_repl", "Anjuta");
 	gnome_dialog_close_hides (GNOME_DIALOG (dialog2), TRUE);
 
 	dialog_vbox2 = GNOME_DIALOG (dialog2)->vbox;
 	gtk_widget_show (dialog_vbox2);
 
-	frame8 = gtk_frame_new (_(" Regexp/String to search "));
+	frame8 = gtk_frame_new (_(" RegExp/String to search "));
 	gtk_widget_show (frame8);
 	gtk_box_pack_start (GTK_BOX (dialog_vbox2), frame8, TRUE, TRUE, 0);
 
@@ -388,7 +389,7 @@ create_find_replace_gui (FindAndReplace * fr)
 	gtk_container_add (GTK_CONTAINER (frame13), vbox7);
 
 	radiobutton20 =
-		gtk_radio_button_new_with_label (vbox7_group, _("Regexp"));
+		gtk_radio_button_new_with_label (vbox7_group, _("RegExp"));
 	vbox7_group =
 		gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton20));
 	gtk_widget_show (radiobutton20);
@@ -506,7 +507,7 @@ create_find_replace_gui (FindAndReplace * fr)
 	gtk_widget_grab_focus (combo_entry2);
 }
 
-GtkWidget *
+static GtkWidget *
 create_replace_messagebox ()
 {
 	GtkWidget *replace_mesgbox;
@@ -550,7 +551,7 @@ create_replace_messagebox ()
 	return replace_mesgbox;
 }
 
-void
+static void
 on_replace_text_ok_clicked (GtkButton * button, gpointer user_data)
 {
 	TextEditor *te;
@@ -630,19 +631,19 @@ on_replace_text_ok_clicked (GtkButton * button, gpointer user_data)
 	}
 }
 
-void
+static void
 on_replace_text_cancel_clicked (GtkButton * button, gpointer user_data)
 {
 	find_replace_hide ((FindAndReplace *) user_data);
 }
 
-void
+static void
 on_replace_text_help_clicked (GtkButton * button, gpointer user_data)
 {
 
 }
 
-gboolean
+static gboolean
 on_replace_text_delete_event (GtkWidget * widget,
 			      GdkEvent * event, gpointer user_data)
 {
