@@ -25,7 +25,7 @@
 #include "anjuta.h"
 #include "mainmenu_callbacks.h"
 #include "main_menubar_def.h"
-
+#include "fileselection.h"
 
 void on_file_menu_realize (GtkWidget * widget, gpointer data);
 
@@ -80,9 +80,6 @@ create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
 	mb->edit.autocomplete = edit1_menu_uiinfo[11].widget;
 	mb->edit.calltip = edit1_menu_uiinfo[12].widget;
 	
-	/* unimplemented */
-	gtk_widget_hide (edit1_menu_uiinfo[12].widget);
-	
 	mb->edit.find = edit1_menu_uiinfo[14].widget;
 	mb->edit.find_in_files = edit1_menu_uiinfo[15].widget;
 	mb->edit.find_replace = edit1_menu_uiinfo[16].widget;
@@ -199,8 +196,8 @@ create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
 
 	mb->debug.cont = execution1_submenu_uiinfo[0].widget;
 	mb->debug.step_in = execution1_submenu_uiinfo[1].widget;
-	mb->debug.step_out = execution1_submenu_uiinfo[2].widget;
-	mb->debug.step_over = execution1_submenu_uiinfo[3].widget;
+	mb->debug.step_over = execution1_submenu_uiinfo[2].widget;
+	mb->debug.step_out = execution1_submenu_uiinfo[3].widget;
 	mb->debug.run_to_cursor = execution1_submenu_uiinfo[4].widget;
 
 	for (i = 0; i < 5; i++)
@@ -266,16 +263,14 @@ create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
 	for (i = 0; i < 6; i++)
 		gtk_widget_ref (settings1_menu_uiinfo[i].widget);
 
-	mb->help.contents = help1_menu_uiinfo[0].widget;
-	mb->help.index = help1_menu_uiinfo[1].widget;
+	mb->help.gnome = help1_menu_uiinfo[2].widget;
 	mb->help.man = help1_menu_uiinfo[3].widget;
 	mb->help.info = help1_menu_uiinfo[4].widget;
-	mb->help.search = help1_menu_uiinfo[5].widget;
-	mb->help.about = help1_menu_uiinfo[7].widget;
-	for (i = 1; i < 8; i++)
+	mb->help.context_help = help1_menu_uiinfo[6].widget;
+	mb->help.search = help1_menu_uiinfo[7].widget;
+	mb->help.about = help1_menu_uiinfo[17].widget;
+	for (i = 1; i < 18; i++)
 		gtk_widget_ref (help1_menu_uiinfo[i].widget);
-	gtk_menu_item_right_justify (GTK_MENU_ITEM
-				     (menubar1_uiinfo[11].widget));
 
 	/* unimplemented */
 	gtk_widget_hide (menubar1_uiinfo[8].widget);
@@ -335,7 +330,7 @@ main_menu_unref ()
 		gtk_widget_unref (windows1_menu_uiinfo[i].widget);
 	for (i = 0; i < 6; i++)
 		gtk_widget_unref (settings1_menu_uiinfo[i].widget);
-	for (i = 1; i < 8; i++)
+	for (i = 1; i < 18; i++)
 		gtk_widget_unref (help1_menu_uiinfo[i].widget);
 }
 
@@ -390,7 +385,7 @@ void
 on_file_menu_realize (GtkWidget * widget, gpointer data)
 {
 	GtkWidget *submenu =
-		create_submenu (_("Resent Files    "), app->recent_files,
+		create_submenu (_("Recent Files    "), app->recent_files,
 				GTK_SIGNAL_FUNC
 				(on_recent_files_menu_item_activate));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (widget), submenu);
@@ -423,8 +418,6 @@ on_recent_projects_menu_item_activate (GtkMenuItem * item, gchar * data)
 				("You have a project opened. Close it first."));
 		return;
 	}
-	gtk_file_selection_set_filename (GTK_FILE_SELECTION
-					 (app->project_dbase->
-					  fileselection_open), data);
+	fileselection_set_filename (app->project_dbase->fileselection_open, data);
 	project_dbase_load_project (app->project_dbase, TRUE);
 }
