@@ -41,44 +41,44 @@ static GnomeUIInfo file1_menu_uiinfo[] = {
 	 GDK_N, GDK_MOD1_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Open ..."),
-	 N_("Open Text File"),
+	 N_("Open file"),
 	 on_open1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN,
 	 GDK_O, GDK_CONTROL_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Save"),
-	 N_("Save Current File"),
+	 N_("Save current file"),
 	 on_save1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE,
 	 GDK_S, GDK_CONTROL_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Save _As ..."),
-	 N_("Save the current File to a different file"),
+	 N_("Save the current file with a different name"),
 	 on_save_as1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE_AS,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Save A_ll"),
-	 N_("Save all currently opened Files, execpt Newfiles"),
+	 N_("Save all currently open files, except new files"),
 	 on_save_all1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE,
 	 GDK_L, GDK_CONTROL_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Close File"),
-	 N_("Close Current File"),
+	 N_("Close current file"),
 	 on_close_file1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE,
 	 GDK_D, GDK_MOD1_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Reload F_ile"),
-	 N_("Reload Current File"),
+	 N_("Reload current file"),
 	 on_reload_file1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REVERT,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("N_ew Project ..."),
-	 N_("Create a project using application widzard"),
+	 N_("Create a Project using application wizard"),
 	 on_new_project1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 0, 0, NULL},
@@ -116,7 +116,7 @@ static GnomeUIInfo file1_menu_uiinfo[] = {
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Print ..."),
-	 N_("Print the current File"),
+	 N_("Print the current file"),
 	 on_print1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PRINT,
 	 GDK_P, GDK_MOD1_MASK, NULL},
@@ -141,19 +141,19 @@ static GnomeUIInfo file1_menu_uiinfo[] = {
 static GnomeUIInfo transform1_submenu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("_Make Selection Uppercase"),
-	 N_("Make the selected text to uppercase"),
+	 N_("Make the selected text uppercase"),
 	 on_transform_upper1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Make Selection Lowercase"),
-	 N_("Make the selected text to lowercase"),
+	 N_("Make the selected text lowercase"),
 	 on_transform_lower1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Convert EOL chars to LF"),
-	 N_("Convert End of line characters to unix EOL (line feed: LF)"),
+	 N_("Convert End Of Line characters to UNIX EOL (line feed: LF)"),
 	 on_transform_eolchars1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -185,7 +185,7 @@ static GnomeUIInfo select1_submenu_uiinfo[] = {
 static GnomeUIInfo goto1_submenu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("_Goto Line no ..."),
-	 N_("Go to a perticular line no. in the editor"),
+	 N_("Go to a particular line in the editor"),
 	 on_goto_line_no1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_G, GDK_CONTROL_MASK, NULL},
@@ -194,31 +194,31 @@ static GnomeUIInfo goto1_submenu_uiinfo[] = {
 	 N_("Go to the matching brace in the editor"),
 	 on_goto_matchbrace1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
-	 GDK_B, GDK_CONTROL_MASK, NULL},
+	 GDK_M, GDK_CONTROL_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Goto start of block"),
 	 N_("Go to the start of the current block"),
 	 on_goto_block_start1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
-	 GDK_G, GDK_CONTROL_MASK, NULL},
+	 GDK_S, GDK_CONTROL_MASK | GDK_MOD1_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Goto end of block"),
 	 N_("Go to the end of the current block"),
 	 on_goto_block_end1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
-	 GDK_G, GDK_CONTROL_MASK, NULL},
+	 GDK_E, GDK_CONTROL_MASK | GDK_MOD1_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Goto previous mesg"),
 	 N_("Go to previous message"),
 	 on_goto_prev_mesg1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
-	 GDK_G, GDK_CONTROL_MASK, NULL},
+	 GDK_P, GDK_CONTROL_MASK | GDK_MOD1_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Goto next mesg"),
 	 N_("Go to next message"),
 	 on_goto_next_mesg1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
-	 GDK_G, GDK_CONTROL_MASK, NULL},
+	 GDK_N, GDK_CONTROL_MASK | GDK_MOD1_MASK, NULL},
 	GNOMEUIINFO_END
 };
 
@@ -232,7 +232,7 @@ static GnomeUIInfo edit1_menu_uiinfo[] = {
 
 	{
 	 GNOME_APP_UI_ITEM, N_("_Redo"),
-	 N_("Redo the last udone action"),
+	 N_("Redo the last undone action"),
 	 on_redo1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REDO,
 	 GDK_R, GDK_CONTROL_MASK, NULL},
@@ -287,7 +287,7 @@ static GnomeUIInfo edit1_menu_uiinfo[] = {
 	
 	{
 	 GNOME_APP_UI_ITEM, N_("_AutoComplete"),
-	 N_("Auto complete the current word"),
+	 N_("AutoComplete the current word"),
 	 on_autocomplete1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_Return, GDK_CONTROL_MASK, NULL},
@@ -303,24 +303,24 @@ static GnomeUIInfo edit1_menu_uiinfo[] = {
 	
 	{
 	 GNOME_APP_UI_ITEM, N_("_Find ..."),
-	 N_("Search a string or regexp in the editor"),
+	 N_("Search for a string or regexp in the editor"),
 	 on_find1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,
-	 GDK_F, GDK_MOD1_MASK, NULL},
+	 GDK_F, GDK_CONTROL_MASK, NULL},
 	
 	{
 	 GNOME_APP_UI_ITEM, N_("Fin_d in files ..."),
-	 N_("Search a string in multiple files or directories"),
+	 N_("Search for a string in multiple files or directories"),
 	 on_find_in_files1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	
 	{
 	GNOME_APP_UI_ITEM, N_("Find and R_eplace ..."),
-	N_("Search and replace a string or regexp with another string"),
+	N_("Search for and replace a string or regexp with another string"),
 	on_find_and_replace1_activate, NULL, NULL,
 	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SRCHRPL,
-	GDK_R, GDK_MOD1_MASK, NULL},
+	GDK_R, GDK_CONTROL_MASK, NULL},
 	
 	GNOMEUIINFO_SEPARATOR,
 	
@@ -334,8 +334,8 @@ static GnomeUIInfo edit1_menu_uiinfo[] = {
 	GNOMEUIINFO_SEPARATOR,
 	
 	{
-	 GNOME_APP_UI_ITEM, N_("Ed_it Application GUIs ..."),
-	 N_("Edit your application GUIs with glade GUI editor"),
+	 GNOME_APP_UI_ITEM, N_("Ed_it Application GUI ..."),
+	 N_("Edit application GUI with the Glade GUI editor"),
 	 on_edit_app_gui1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_E, GDK_MOD1_MASK, NULL},
@@ -345,43 +345,43 @@ static GnomeUIInfo edit1_menu_uiinfo[] = {
 
 static GnomeUIInfo toolbar1_submenu_uiinfo[] = {
 	{
-	 GNOME_APP_UI_TOGGLEITEM, N_("_Main Tolbar"),
-	 N_("Hide/Unhide main toolbar"),
+	 GNOME_APP_UI_TOGGLEITEM, N_("_Main Toolbar"),
+	 N_("Hide/Unhide Main toolbar"),
 	 on_main_toolbar1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BLANK,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
-	 GNOME_APP_UI_TOGGLEITEM, N_("_Exended Toolbar"),
-	 N_("Hide/Unhide extended toolbar"),
+	 GNOME_APP_UI_TOGGLEITEM, N_("_Extended Toolbar"),
+	 N_("Hide/Unhide Extended toolbar"),
 	 on_extended_toolbar1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Tags Toolbar"),
-	 N_("Hide/Unhide tags toolbar"),
+	 N_("Hide/Unhide Tags toolbar"),
 	 on_tags_toolbar1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Debug Toolbar"),
-	 N_("Hide/Unhide debug toolbar"),
+	 N_("Hide/Unhide Debug toolbar"),
 	 on_debug_toolbar1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Browser Toolbar"),
-	 N_("Hide/Unhide browser toolbar"),
+	 N_("Hide/Unhide Browser toolbar"),
 	 on_browser_toolbar1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Format Toolbar"),
-	 N_("Hide/Unhide format toolbar"),
+	 N_("Hide/Unhide Format toolbar"),
 	 on_format_toolbar1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -391,37 +391,37 @@ static GnomeUIInfo toolbar1_submenu_uiinfo[] = {
 static GnomeUIInfo editor1_submenu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Line numbers margin"),
-	 N_("Show/Hide Line numbers"),
+	 N_("Show/Hide line numbers"),
 	 on_editor_linenos1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BLANK,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Markers Margin"),
-	 N_("Show/Hide Markers margins"),
+	 N_("Show/Hide markers margin"),
 	 on_editor_markers1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Code fold margin"),
-	 N_("Show/Hide Code fold margin"),
+	 N_("Show/Hide code fold margin"),
 	 on_editor_codefold1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Indentation guides"),
-	 N_("Show/Hide Indentation guides"),
+	 N_("Show/Hide undentation guides"),
 	 on_editor_indentguides1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_White spaces"),
-	 N_("Show/Hide White spaces"),
+	 N_("Show/Hide white spaces"),
 	 on_editor_whitespaces1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Line end characters"),
-	 N_("Hide/Unhide debug toolbar"),
+	 N_("Show/Hide line end characters"),
 	 on_editor_eolchars1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -431,7 +431,7 @@ static GnomeUIInfo editor1_submenu_uiinfo[] = {
 static GnomeUIInfo zoom_text1_submenu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("++ Zoom"),
-	 N_("Zoom text size by 1 unit"),
+	 N_("Increase text zoom by 1 unit"),
 	 on_zoom_text_plus_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -491,7 +491,7 @@ static GnomeUIInfo zoom_text1_submenu_uiinfo[] = {
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("-- Zoom"),
-	 N_("Unzoom text size by 1 unit"),
+	 N_("Reduce text zoom by 1 unit"),
 	 on_zoom_text_minus_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -501,19 +501,19 @@ static GnomeUIInfo zoom_text1_submenu_uiinfo[] = {
 static GnomeUIInfo view1_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("_Messages"),
-	 N_("Show the message window"),
+	 N_("Show/Hide the Message window"),
 	 on_messages1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ALIGN_LEFT,
 	 GDK_F1, GDK_CONTROL_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Project Listing"),
-	 N_("Show the project window"),
+	 N_("Show/Hide the Project window"),
 	 on_project_listing1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ALIGN_LEFT,
 	 GDK_F2, GDK_CONTROL_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("B_ookmarks"),
-	 N_("Show the bookmark window"),
+	 N_("Show the Bookmark window"),
 	 on_bookmarks1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_F3, GDK_CONTROL_MASK, NULL},
@@ -554,7 +554,7 @@ static GnomeUIInfo view1_menu_uiinfo[] = {
 	 GDK_F5, GDK_CONTROL_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Registers"),
-	 N_("Show cpu registers and their contents"),
+	 N_("Show CPU registers and their contents"),
 	 on_registers1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_F6, GDK_CONTROL_MASK, NULL},
@@ -571,14 +571,14 @@ static GnomeUIInfo view1_menu_uiinfo[] = {
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_F8, GDK_CONTROL_MASK, NULL},
 	{
-	 GNOME_APP_UI_ITEM, N_("_Kernal Signals"),
-	 N_("Show the kernal signals editor window"),
+	 GNOME_APP_UI_ITEM, N_("_Kernel Signals"),
+	 N_("Show the kernel signals editor window"),
 	 on_kernal_signals1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_F9, GDK_CONTROL_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Dump Window"),
-	 N_("Show Memory dump window"),
+	 N_("Show memory dump window"),
 	 on_dump_window1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_F10, GDK_CONTROL_MASK, NULL},
@@ -630,7 +630,7 @@ static GnomeUIInfo import_file1_menu_uiinfo[] = {
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
-	 GNOME_APP_UI_ITEM, N_("Doc file"),
+	 GNOME_APP_UI_ITEM, N_("Documentation file"),
 	 NULL,
 	 on_project_doc_file1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
@@ -654,32 +654,32 @@ static GnomeUIInfo project1_menu_uiinfo[] = {
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("Remove"),
-	 NULL,
+	 N_("Remove the current file from the project"),
 	 on_project_remove1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, "READ_ME",
-	 N_("Open the readme file of the project"),
+	 N_("Open the README file of the project"),
 	 on_prj_readme1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, "_TODO",
-	 N_("Open the todo file of the project"),
+	 N_("Open the TODO file of the project"),
 	 on_prj_todo1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, "Change_Log",
-	 N_("Open the changelog file of the project"),
+	 N_("Open the ChangeLog file of the project"),
 	 on_prj_changelog1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, "_NEWS",
-	 N_("Open the news file of the project"),
+	 N_("Open the NEWS file of the project"),
 	 on_prj_news1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 0, 0, NULL},
@@ -702,133 +702,133 @@ static GnomeUIInfo project1_menu_uiinfo[] = {
 static GnomeUIInfo hilitetype1_submenu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("Automatic"),
-	 N_("Automatically determine the hilite style"),
+	 N_("Automatically determine the highlight style"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_AUTOMATIC), NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXEC,
 	 0, 0, NULL},
 	{
-	 GNOME_APP_UI_ITEM, N_("No Hilite style"),
-	 N_("Force the hilite style to None"),
+	 GNOME_APP_UI_ITEM, N_("No Highlight style"),
+	 N_("Force the highlight style to None"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_NONE), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("C and C++"),
-	 N_("Force the hilite style to C and CPP"),
+	 N_("Force the highlight style to C and C++"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_CPP), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
-	 GNOME_APP_UI_ITEM, N_("C and C++ with Gnome"),
-	 N_("Force the hilite style to C and C++ with Gnome"),
+	 GNOME_APP_UI_ITEM, N_("C and C++ with GNOME"),
+	 N_("Force the highlight style to C and C++ with GNOME"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_GCPP), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
-	 GNOME_APP_UI_ITEM, N_("Html"),
-	 N_("Force the hilite style to Html"),
+	 GNOME_APP_UI_ITEM, N_("HTML"),
+	 N_("Force the highlight style to HTML"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_HTML), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
-	 GNOME_APP_UI_ITEM, N_("Xml"),
-	 N_("Force the hilite style to Xml"),
+	 GNOME_APP_UI_ITEM, N_("XML"),
+	 N_("Force the highlight style to XML"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_XML), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
-	 GNOME_APP_UI_ITEM, N_("Java Scricpts"),
-	 N_("Force the hilite style to Java scripts"),
+	 GNOME_APP_UI_ITEM, N_("Javascript"),
+	 N_("Force the highlight style to Javascript"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_JS), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("WScript"),
-	 N_("Force the hilite style to Java scripts"),
+	 N_("Force the highlight style to WScript"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_WSCRIPT), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Makefile"),
-	 N_("Force the hilite style to Perl"),
+	 N_("Force the highlight style to Makefile"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_MAKE), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Java"),
-	 N_("Force the hilite type to Java"),
+	 N_("Force the highlight type to Java"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_JAVA), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("LUA"),
-	 N_("Force the hilite style to LUA"),
+	 N_("Force the highlight style to LUA"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_LUA), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Python"),
-	 N_("Force the hilite style to Python"),
+	 N_("Force the highlight style to Python"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_PYTHON), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Perl"),
-	 N_("Force the hilite style to Perl"),
+	 N_("Force the highlight style to Perl"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_PERL), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("SQL"),
-	 N_("Force the hilite style to SQL"),
+	 N_("Force the highlight style to SQL"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_SQL), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
-	 GNOME_APP_UI_ITEM, N_("PLSQL"),
-	 N_("Force the hilite style to PLSQL"),
+	 GNOME_APP_UI_ITEM, N_("PL/SQL"),
+	 N_("Force the highlight style to PL/SQL"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_PLSQL), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("PHP"),
-	 N_("Force the hilite style to SQL"),
+	 N_("Force the highlight style to PHP"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_PHP), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("LaTex"),
-	 N_("Force the hilite style to LaTex"),
+	 N_("Force the highlight style to LaTex"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_LATEX), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Diff"),
-	 N_("Force the hilite style to Diff"),
+	 N_("Force the highlight style to Diff"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_DIFF), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Pascal"),
-	 N_("Force the hilite type to Pascal"),
+	 N_("Force the highlight style to Pascal"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_PASCAL), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Xcode"),
-	 N_("Force the hilite style to Xcode"),
+	 N_("Force the highlight style to Xcode"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_XCODE), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Prj/Properties"),
-	 N_("Force the hilite style to project/properties files"),
+	 N_("Force the highlight style to project/properties files"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_PROPS), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Conf"),
-	 N_("Force the hilite style to Unix conf files"),
+	 N_("Force the highlight style to UNIX conf files"),
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_CONF), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -838,7 +838,7 @@ static GnomeUIInfo hilitetype1_submenu_uiinfo[] = {
 static GnomeUIInfo format1_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("Auto _Format"),
-	 N_("This will autoformate C and C++ source file"),
+	 N_("Autoformat C and C++ source files"),
 	 on_indent1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ALIGN_LEFT,
 	 0, 0, NULL},
@@ -857,13 +857,13 @@ static GnomeUIInfo format1_menu_uiinfo[] = {
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("_Update tags image"),
-	 N_("This will update the tags image of the project/opened files"),
+	 N_("Update the tags image of the project/opened files"),
 	 on_update_tags1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_FONT,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
-	 GNOME_APP_UI_SUBTREE, N_("Force _Hilite Style"),
+	 GNOME_APP_UI_SUBTREE, N_("Force _Highlight Style"),
 	 NULL,
 	 hilitetype1_submenu_uiinfo, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
@@ -890,7 +890,7 @@ static GnomeUIInfo format1_menu_uiinfo[] = {
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("D_etach Current Document"),
-	 N_("Detach the current editor into a seperate window"),
+	 N_("Detach the current editor into a separate window"),
 	 on_detach1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -921,7 +921,7 @@ static GnomeUIInfo build1_menu_uiinfo[] = {
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("_Install"),
-	 N_("Install the project in your computer"),
+	 N_("Install the project on your system"),
 	 on_install_project1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -947,7 +947,7 @@ static GnomeUIInfo build1_menu_uiinfo[] = {
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("Clea_n"),
-	 N_("Clean your source directory"),
+	 N_("Clean the source directory"),
 	 on_clean_project1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -1031,19 +1031,19 @@ static GnomeUIInfo execution1_submenu_uiinfo[] = {
 	 GDK_F4, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Step _In"),
-	 N_("Single step into functions"),
+	 N_("Single step into function"),
 	 on_execution_step_in1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_F5, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Step O_ver"),
-	 N_("Single step over functions"),
+	 N_("Single step over function"),
 	 on_execution_step_over1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_F6, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Step _Out"),
-	 N_("Single step out of the functions"),
+	 N_("Single step out of the function"),
 	 on_execution_step_out1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_F7, 0, NULL},
@@ -1078,13 +1078,13 @@ static GnomeUIInfo breakpoints1_submenu_uiinfo[] = {
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Disable all Breakpoints"),
-	 N_("This will deactivate all the breakpoints"),
+	 N_("Deactivate all breakpoints"),
 	 on_disable_all_breakpoints1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("C_lear all Breakpoints"),
-	 N_("This will delete all the breakpoints"),
+	 N_("Delete all breakpoints"),
 	 on_clear_breakpoints1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE,
 	 0, 0, NULL},
@@ -1094,49 +1094,49 @@ static GnomeUIInfo breakpoints1_submenu_uiinfo[] = {
 static GnomeUIInfo info1_submenu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("Info _Target Files"),
-	 N_("The files which the debugger is active with"),
+	 N_("Display information on the files the debugger is active with"),
 	 on_info_targets_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Info _Program"),
-	 N_("Get the information about the execution status of the program"),
+	 N_("Display information on the execution status of the program"),
 	 on_info_program_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
-	 GNOME_APP_UI_ITEM, N_("Info _Kernal User Struct"),
-	 N_("Get the contents of kernel 'struct user' for current child"),
+	 GNOME_APP_UI_ITEM, N_("Info _Kernel User Struct"),
+	 N_("Display the contents of kernel 'struct user' for current child"),
 	 on_info_udot_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Info _Threads"),
-	 N_("Get the IDs of currently known threads"),
+	 N_("Display the IDs of currently known threads"),
 	 on_info_threads_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Info _Global variables"),
-	 N_("All the global and static variables of the program"),
+	 N_("Display all global and static variables of the program"),
 	 on_info_variables_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Info _Local variables"),
-	 N_("All the local variables of the current frame"),
+	 N_("Display local variables of the current frame"),
 	 on_info_locals_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Info _Current Frame"),
-	 N_("Show the information about the current frame of execution"),
+	 N_("Display information about the current frame of execution"),
 	 on_info_frame_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_BLUE,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Info Function _Arguments"),
-	 N_("Function arguments of the current frame"),
+	 N_("Display function arguments of the current frame"),
 	 on_info_args_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -1153,19 +1153,19 @@ static GnomeUIInfo debug1_menu_uiinfo[] = {
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("Load E_xecutable ..."),
-	 N_("Open the executable for debuging"),
+	 N_("Open the executable for debugging"),
 	 on_debugger_open_exec_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Load _Core file ..."),
-	 N_("Load a core file to disect"),
+	 N_("Load a core file to dissect"),
 	 on_debugger_load_core_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REVERT,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Attach to Process ..."),
-	 N_("Attach to an already running program"),
+	 N_("Attach to a running program"),
 	 on_debugger_attach_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ATTACH,
 	 0, 0, NULL},
@@ -1178,26 +1178,26 @@ static GnomeUIInfo debug1_menu_uiinfo[] = {
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("S_top Program"),
-	 N_("Stop the debugging program"),
+	 N_("Stop the program being debugged"),
 	 on_debugger_stop_prog_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_STOP,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Detach Debugger"),
-	 N_("Detach the program if you have attached to it"),
+	 N_("Detach from an attached program"),
 	 on_debugger_detach_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("I_nterrupt Program"),
-	 N_("Interrupt the program execution"),
+	 N_("Interrupt execution of the program"),
 	 on_debugger_interrupt_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
-	 GDK_F1, 0, NULL},
+	 GDK_I, GDK_CONTROL_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Si_gnal to Process"),
-	 N_("Send a kernel signal to the debugging process"),
+	 N_("Send a kernel signal to the process being debugged"),
 	 on_debugger_signal_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -1224,20 +1224,20 @@ static GnomeUIInfo debug1_menu_uiinfo[] = {
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("Ins_pect/Evaluate ..."),
-	 N_("Inspect or evaluate an expression or a variable"),
+	 N_("Inspect or evaluate an expression or variable"),
 	 on_debugger_inspect_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_OPEN,
-	 GDK_F2, 0, NULL},
+	 GDK_P, GDK_CONTROL_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Add Expression in _Watch ..."),
-	 N_("Add expression or a variable in the watch"),
+	 N_("Add expression or variable to the watch"),
 	 on_debugger_add_watch_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
-	 GDK_F2, 0, NULL},
+	 GDK_W, GDK_CONTROL_MASK, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("St_op Debugger"),
-	 N_("Say good bye to the debugger"),
+	 N_("Say goodbye to the debugger"),
 	 on_debugger_stop_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_STOP,
 	 0, 0, NULL},
@@ -1307,7 +1307,7 @@ static GnomeUIInfo utilities1_menu_uiinfo[] = {
 static GnomeUIInfo windows1_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("_Create New Window"),
-	 N_("Start another Anjuta application"),
+	 N_("Open a new file window"),
 	 on_windows1_new_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 0, 0, NULL},
@@ -1327,7 +1327,7 @@ static GnomeUIInfo windows1_menu_uiinfo[] = {
 static GnomeUIInfo settings1_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("_Compiler and Linker Settings ..."),
-	 N_("Settings that are meant for compiler and linker"),
+	 N_("Settings for the compiler and linker"),
 	 on_set_compiler1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF,
 	 0, 0, NULL},
@@ -1362,6 +1362,12 @@ static GnomeUIInfo settings1_menu_uiinfo[] = {
 static GnomeUIInfo help1_menu_uiinfo[] = {
 	GNOMEUIINFO_HELP ("anjuta"),
 	GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_ITEM, N_("Browse Gnome API Pages"),
+	 N_("The gnome API pages"),
+	 on_gnome_pages1_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_RED,
+	 GDK_F1, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Browse Man Pages"),
 	 N_("The good old manual pages"),
@@ -1374,6 +1380,13 @@ static GnomeUIInfo help1_menu_uiinfo[] = {
 	 on_info_pages1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_RED,
 	 0, 0, NULL},
+	GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_ITEM, N_("Context Help"),
+	 N_("Search help for the current word in the editor"),
+	 on_context_help_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,
+ 	 GDK_H, GDK_CONTROL_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Search a topic"),
 	 N_("May I help you?"),
@@ -1381,6 +1394,44 @@ static GnomeUIInfo help1_menu_uiinfo[] = {
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_ITEM, N_("Anjuta Home site"),
+	 N_("Online documentation and resources"),
+	 on_url_activate, "http://anjuta.sourceforge.net", NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_ITEM, N_("Libraries API references"),
+	 N_("Online reference library for GDK, GLib, GNOME etc.."),
+	 on_url_activate, "http://www.lidn.org", NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("Report Bugs"),
+	 N_("Submit a bug report for Anjuta"),
+	 on_url_activate, "http://sourceforge.net/tracker/?atid=114222&group_id=14222&func=browse", NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("Request Features"),
+	 N_("Submit a feature request for Anjtua"),
+	 on_url_activate, "http://sourceforge.net/tracker/?atid=364222&group_id=14222&func=browse", NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("Submit patches"),
+	 N_("Submit patches for Anjuta"),
+	 on_url_activate, "http://sourceforge.net/tracker/?atid=314222&group_id=14222&func=browse", NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("Ask a question"),
+	 N_("Submit a question for FAQs"),
+	 on_url_activate, "mailto:anjuta-list@lists.sourceforge.net", NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_ABOUT_ITEM (on_about1_activate, NULL),
 	GNOMEUIINFO_END
 };
