@@ -40,16 +40,17 @@
 #include "messages.h"
 #include "compile.h"
 #include "launcher.h"
-#include "appwidzard.h"
+#include "appwizard.h"
 #include "project_dbase.h"
 #include "debugger.h"
 #include "breakpoints_cbs.h"
 #include "goto_line.h"
-#include "support.h"
+#include "resources.h"
 #include "executer.h"
 #include "controls.h"
 #include "signals_cbs.h"
 #include "watch_cbs.h"
+#include "help.h"
 #include "Scintilla.h"
 #include "ScintillaWidget.h"
 
@@ -169,7 +170,7 @@ on_reload_file1_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_new_project1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	app_widzard_proceed ();
+	app_wizard_proceed ();
 }
 
 void
@@ -509,13 +510,25 @@ on_edit_app_gui1_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_messages1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	messages_show (app->messages, MESSAGE_TYPE_END);
+	gboolean state;
+	state = app->messages->is_showing;
+	if(state) {
+		messages_hide (app->messages);
+	} else {
+		messages_show (app->messages, MESSAGE_TYPE_END);
+	}
 }
 
 void
 on_project_listing1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	project_dbase_show (app->project_dbase);
+	gboolean state;
+	state = app->project_dbase->is_showing;
+	if(state) {
+		project_dbase_hide (app->project_dbase);
+	} else {
+		project_dbase_show (app->project_dbase);
+	}
 }
 
 void
@@ -584,7 +597,7 @@ on_editor_linenos1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GList *node;
 	TextEditor *te;
 	state = GTK_CHECK_MENU_ITEM (menuitem)->active;
-	preferences_set_int (app->preferences, "margin.linenumber.view",
+	preferences_set_int (app->preferences, "margin.linenumber.visible",
 			     state);
 	node = app->text_editor_list;
 	while (node)
@@ -603,7 +616,7 @@ on_editor_markers1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GList *node;
 	TextEditor *te;
 	state = GTK_CHECK_MENU_ITEM (menuitem)->active;
-	preferences_set_int (app->preferences, "margin.marker.view", state);
+	preferences_set_int (app->preferences, "margin.marker.visible", state);
 	node = app->text_editor_list;
 	while (node)
 	{
@@ -620,7 +633,7 @@ on_editor_codefold1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GList *node;
 	TextEditor *te;
 	state = GTK_CHECK_MENU_ITEM (menuitem)->active;
-	preferences_set_int (app->preferences, "margin.fold.view", state);
+	preferences_set_int (app->preferences, "margin.fold.visible", state);
 	node = app->text_editor_list;
 	while (node)
 	{
@@ -953,6 +966,7 @@ on_indent1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	if (te == NULL)
 		return;
 	text_editor_autoformat (te);
+	anjuta_update_title();
 }
 
 void
@@ -982,7 +996,7 @@ on_update_tags1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gint i;
 
 	tags_manager_freeze (app->tags_manager);
-	tags_manager_clear (app->tags_manager);
+	/*tags_manager_clear (app->tags_manager);*/
 
 	if (app->project_dbase->project_is_open)
 	{
@@ -990,6 +1004,7 @@ on_update_tags1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	}
 	else
 	{
+		tags_manager_clear (app->tags_manager);
 		for (i = 0; i < g_list_length (app->text_editor_list); i++)
 		{
 			te = g_list_nth_data (app->text_editor_list, i);
@@ -1712,6 +1727,15 @@ on_index1_activate (GtkMenuItem * menuitem, gpointer user_data)
 		anjuta_register_child_process (pid, NULL, NULL);
 }
 
+void
+on_gnome_pages1_activate            (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+	if (anjuta_is_installed ("devhelp", TRUE))
+	{
+		anjuta_res_help_search (NULL);
+	}
+}
 
 void
 on_man_pages1_activate (GtkMenuItem * menuitem, gpointer user_data)
@@ -1749,10 +1773,33 @@ on_info_pages1_activate (GtkMenuItem * menuitem, gpointer user_data)
 		anjuta_register_child_process (pid, NULL, NULL);
 }
 
+void
+on_context_help_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+	TextEditor* te;
+	gboolean ret;
+	gchar buffer[1000];
+	
+	te = anjuta_get_current_text_editor();
+	if(!te) return;
+	ret = aneditor_command (te->editor_id, ANE_GETCURRENTWORD, (long)buffer, (long)sizeof(buffer));
+	if (ret == FALSE) return;
+	anjuta_help_search(app->help_system, buffer);
+}
+
 void
 on_search_a_topic1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	anjuta_not_implemented (__FILE__, __LINE__);
+	anjuta_help_show(app->help_system);
+}
+
+void
+on_url_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+	if (user_data)
+	{
+		gnome_url_show(user_data);
+	}
 }
 
 void
