@@ -29,7 +29,7 @@
 #include "messages.h"
 #include "utilities.h"
 #include "pixmaps.h"
-#include "support.h"
+#include "resources.h"
 #include "properties.h"
 
 static void on_mesg_win_but1_clicked (GtkButton * but, gpointer data);
@@ -197,7 +197,6 @@ messages_hide (Messages * m)
 void
 messages_clear (Messages * m, MessageType type)
 {
-	gint i;
 	g_return_if_fail (m != NULL);
 	g_return_if_fail (type < MESSAGE_TYPE_END);
 
@@ -490,6 +489,7 @@ create_mesg_gui (Messages * m)
 	gtk_widget_ref (mesg_gui);
 	gtk_widget_set_usize (mesg_gui, 200, 70);
 	gtk_window_set_title (GTK_WINDOW (mesg_gui), _("Messages"));
+	gtk_window_set_wmclass (GTK_WINDOW (mesg_gui), "messages", "Anjuta");
 
 	eventbox1 = gtk_event_box_new ();
 	gtk_widget_ref (eventbox1);
@@ -530,7 +530,7 @@ create_mesg_gui (Messages * m)
 	gtk_button_set_relief (GTK_BUTTON (button5), GTK_RELIEF_NONE);
 	gtk_container_add (GTK_CONTAINER (frame3), button5);
 	pix_lab =
-		create_xpm_label_box (mesg_gui, ANJUTA_PIXMAP_MINI_BUILD,
+		create_xpm_label_box (mesg_gui, ANJUTA_PIXMAP_MINI_BUILD, FALSE,
 				      _("Build"));
 	gtk_widget_show (pix_lab);
 	gtk_container_add (GTK_CONTAINER (button5), pix_lab);
@@ -546,7 +546,7 @@ create_mesg_gui (Messages * m)
 	gtk_button_set_relief (GTK_BUTTON (button6), GTK_RELIEF_NONE);
 	gtk_container_add (GTK_CONTAINER (frame3), button6);
 	pix_lab =
-		create_xpm_label_box (mesg_gui, ANJUTA_PIXMAP_MINI_DEBUG,
+		create_xpm_label_box (mesg_gui, ANJUTA_PIXMAP_MINI_DEBUG, FALSE,
 				      _("Debug"));
 	gtk_widget_show (pix_lab);
 	gtk_container_add (GTK_CONTAINER (button6), pix_lab);
@@ -562,7 +562,7 @@ create_mesg_gui (Messages * m)
 	gtk_button_set_relief (GTK_BUTTON (button7), GTK_RELIEF_NONE);
 	gtk_container_add (GTK_CONTAINER (frame3), button7);
 	pix_lab =
-		create_xpm_label_box (mesg_gui, ANJUTA_PIXMAP_MINI_FIND,
+		create_xpm_label_box (mesg_gui, ANJUTA_PIXMAP_MINI_FIND, FALSE,
 				      _("Find"));
 	gtk_widget_show (pix_lab);
 	gtk_container_add (GTK_CONTAINER (button7), pix_lab);
@@ -578,7 +578,7 @@ create_mesg_gui (Messages * m)
 	gtk_button_set_relief (GTK_BUTTON (button8), GTK_RELIEF_NONE);
 	gtk_container_add (GTK_CONTAINER (frame3), button8);
 	pix_lab =
-		create_xpm_label_box (mesg_gui, ANJUTA_PIXMAP_MINI_CVS,
+		create_xpm_label_box (mesg_gui, ANJUTA_PIXMAP_MINI_CVS, FALSE,
 				      _("CVS"));
 	gtk_widget_show (pix_lab);
 	gtk_container_add (GTK_CONTAINER (button8), pix_lab);
@@ -594,7 +594,7 @@ create_mesg_gui (Messages * m)
 	gtk_button_set_relief (GTK_BUTTON (button1), GTK_RELIEF_NONE);
 	gtk_container_add (GTK_CONTAINER (frame2), button1);
 	pix_lab =
-		create_xpm_label_box (mesg_gui, ANJUTA_PIXMAP_MINI_DOCK,
+		create_xpm_label_box (mesg_gui, ANJUTA_PIXMAP_MINI_DOCK, FALSE,
 				      _("Dock"));
 	gtk_widget_show (pix_lab);
 	gtk_container_add (GTK_CONTAINER (button1), pix_lab);
@@ -1145,7 +1145,7 @@ on_mesg_win_but_event (GtkWidget * widget,
 		return FALSE;
 }
 
-void
+static void
 on_mesg_win_orien_changed (GtkToolbar * t, GtkOrientation or, gpointer data)
 {
 }
