@@ -29,7 +29,7 @@
 
 #include "anjuta.h"
 #include "messages.h"
-#include "support.h"
+#include "resources.h"
 #include "preferences.h"
 #include "properties.h"
 
@@ -37,9 +37,9 @@ gchar *format_style[] = {
 	"Custom style", " -i8 -bl -bls -bli0 -ss",
 	"GNU coding style", " -gnu",
 	"Kernighan & Ritchie style", " -kr",
-	"Original Berkeyley style", " -org",
+	"Original Berkeley style", " -orig",
 	"Style of Kangleipak", " -i8 -sc -bli0 -bl0 -cbi0 -ss",
-	"Hello world style", "  -gnu -i0 -bli0 -cbi0 -cdb -sc -bl0 -ss",
+	"Hello World style", "  -gnu -i0 -bli0 -cbi0 -cdb -sc -bl0 -ss",
 	"Crazy boy style", " ",
 	NULL, NULL
 };
@@ -142,6 +142,7 @@ create_preferences_gui (Preferences * pr)
 	gtk_window_set_policy (GTK_WINDOW (dialog1), FALSE, FALSE, FALSE);
 	gnome_dialog_close_hides (GNOME_DIALOG (dialog1), TRUE);
 	window2 = dialog1;
+	gtk_window_set_wmclass (GTK_WINDOW (window2), "preferences", "Anjuta");
 
 	pr->widgets.window = dialog1;
 
@@ -176,7 +177,7 @@ create_preferences_gui (Preferences * pr)
 	page2 = create_preferences_page2 (pr);
 	gtk_container_add (GTK_CONTAINER (notebook2), page2);
 
-	label1 = gtk_label_new (_("Editor (part 1)"));
+	label1 = gtk_label_new (_("Styles"));
 	gtk_widget_show (label1);
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook2),
 				    gtk_notebook_get_nth_page (GTK_NOTEBOOK
@@ -186,7 +187,7 @@ create_preferences_gui (Preferences * pr)
 	page3 = create_preferences_page3 (pr);
 	gtk_container_add (GTK_CONTAINER (notebook2), page3);
 
-	label12 = gtk_label_new (_("Editor (part 2)"));
+	label12 = gtk_label_new (_("Editor"));
 	gtk_widget_show (label12);
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook2),
 				    gtk_notebook_get_nth_page (GTK_NOTEBOOK
@@ -520,7 +521,7 @@ create_preferences_page1 (Preferences * p)
 
 	checkbutton1 =
 		gtk_check_button_new_with_label (_
-						 ("Keep going when some targets can't be made."));
+						 ("Keep going when some targets cannot be made"));
 	gtk_widget_show (checkbutton1);
 	gtk_box_pack_start (GTK_BOX (vbox1), checkbutton1, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (checkbutton1), 5);
@@ -534,14 +535,14 @@ create_preferences_page1 (Preferences * p)
 
 	checkbutton3 =
 		gtk_check_button_new_with_label (_
-						 ("Produce debugging outputs."));
+						 ("Produce debugging outputs"));
 	gtk_widget_show (checkbutton3);
 	gtk_box_pack_start (GTK_BOX (vbox1), checkbutton3, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (checkbutton3), 5);
 
 	checkbutton6 =
 		gtk_check_button_new_with_label (_
-						 ("Warn when an undefined variable is referenced."));
+						 ("Warn when an undefined variable is referenced"));
 	gtk_widget_show (checkbutton6);
 	gtk_box_pack_start (GTK_BOX (vbox1), checkbutton6, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (checkbutton6), 5);
@@ -585,6 +586,7 @@ static GtkWidget *
 create_preferences_page2 (Preferences * p)
 {
 	GtkWidget *window1;
+	GtkWidget *frame;
 	GtkWidget *vbox1;
 	GtkWidget *hbox1;
 	GtkWidget *label2;
@@ -609,41 +611,33 @@ create_preferences_page2 (Preferences * p)
 	GtkWidget *checkbutton6;
 	GtkWidget *checkbutton7;
 	GtkWidget *table2;
-	GtkWidget *checkbutton9;
-	GtkObject *spinbutton2_adj;
-	GtkWidget *spinbutton2;
-	GtkObject *spinbutton3_adj;
-	GtkWidget *spinbutton3;
-	GtkWidget *checkbutton10;
-	GtkWidget *checkbutton12;
-	GtkWidget *checkbutton11;
-	GtkWidget *checkbutton8;
-	GtkObject *spinbutton4_adj;
-	GtkWidget *spinbutton4;
-	GtkWidget *vseparator1;
-	GtkObject *spinbutton5_adj;
-	GtkWidget *spinbutton5;
-	GtkObject *spinbutton6_adj;
-	GtkWidget *spinbutton6;
 	GtkWidget *label6;
 	GtkWidget *label7;
 	GtkWidget *label8;
 	GtkWidget *label9;
-	GtkWidget *label10;
+	GtkWidget *colorpicker3;
+	GtkWidget *colorpicker4;
+	GtkWidget *colorpicker5;
+	GtkWidget *colorpicker6;
 	GtkWidget *fontpicker1;
 	GList *s_list;
 	gint i;
 
 	window1 = p->widgets.window;
 
+	frame = gtk_frame_new (NULL);
+	gtk_widget_show (frame);
+	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
+	
 	vbox1 = gtk_vbox_new (FALSE, 5);
 	gtk_widget_show (vbox1);
+	gtk_container_add (GTK_CONTAINER(frame), vbox1);
 
 	hbox1 = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, TRUE, 0);
 
-	label2 = gtk_label_new (_("Select Hilite item to edit:"));
+	label2 = gtk_label_new (_("Select Highlight item to edit:"));
 	gtk_widget_show (label2);
 	gtk_box_pack_start (GTK_BOX (hbox1), label2, FALSE, FALSE, 0);
 	gtk_misc_set_padding (GTK_MISC (label2), 5, 0);
@@ -667,7 +661,7 @@ create_preferences_page2 (Preferences * p)
 	combo_entry2 = GTK_COMBO (combo2)->entry;
 	gtk_widget_show (combo_entry2);
 
-	frame1 = gtk_frame_new (_(" Hilite Style "));
+	frame1 = gtk_frame_new (_(" Highlight Style "));
 	gtk_widget_show (frame1);
 	gtk_box_pack_start (GTK_BOX (vbox1), frame1, FALSE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (frame1), 5);
@@ -784,15 +778,161 @@ create_preferences_page2 (Preferences * p)
 			  (GtkAttachOptions) (0), 0, 0);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton7), TRUE);
 
-	table2 = gtk_table_new (5, 4, FALSE);
+	table2 = gtk_table_new (4, 4, FALSE);
 	gtk_widget_show (table2);
-	gtk_box_pack_start (GTK_BOX (vbox1), table2, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox1), table2, TRUE, TRUE, 2);
+	gtk_container_set_border_width (GTK_CONTAINER (table2), 5);
 	gtk_table_set_row_spacings (GTK_TABLE (table2), 2);
 	gtk_table_set_col_spacings (GTK_TABLE (table2), 5);
 
+	label6 = gtk_label_new (_("Caret color:"));
+	gtk_widget_show (label6);
+	gtk_misc_set_alignment (GTK_MISC (label6), 0, -1);
+	gtk_table_attach (GTK_TABLE (table2), label6, 0, 1, 0, 1,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+
+	colorpicker3 = gnome_color_picker_new ();
+	gtk_widget_show (colorpicker3);
+	gtk_table_attach (GTK_TABLE (table2), colorpicker3, 1, 2, 0, 1,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+
+	label7 = gtk_label_new (_("Calltip color:"));
+	gtk_widget_show (label7);
+	gtk_misc_set_alignment (GTK_MISC (label7), 0, -1);
+	gtk_table_attach (GTK_TABLE (table2), label7, 0, 1, 1, 2,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+
+	colorpicker4 = gnome_color_picker_new ();
+	gtk_widget_show (colorpicker4);
+	gtk_table_attach (GTK_TABLE (table2), colorpicker4, 1, 2, 1, 2,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+
+	label8 = gtk_label_new (_("Selection Foreground:"));
+	gtk_widget_show (label8);
+	gtk_misc_set_alignment (GTK_MISC (label8), 0, -1);
+	gtk_table_attach (GTK_TABLE (table2), label8, 2, 3, 0, 1,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+
+	colorpicker5 = gnome_color_picker_new ();
+	gtk_widget_show (colorpicker5);
+	gtk_table_attach (GTK_TABLE (table2), colorpicker5, 3, 4, 0, 1,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+	
+	label9 = gtk_label_new (_("Selection Background:"));
+	gtk_widget_show (label9);
+	gtk_misc_set_alignment (GTK_MISC (label9), 0, -1);
+	gtk_table_attach (GTK_TABLE (table2), label9, 2, 3, 1, 2,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+
+	colorpicker6 = gnome_color_picker_new ();
+	gtk_widget_show (colorpicker6);
+	gtk_table_attach (GTK_TABLE (table2), colorpicker6, 3, 4, 1, 2,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+	
+	gtk_signal_connect (GTK_OBJECT (combo_entry2), "changed",
+			    GTK_SIGNAL_FUNC (on_hilite_style_entry_changed), p);
+	gtk_signal_connect (GTK_OBJECT (checkbutton1), "toggled",
+			    GTK_SIGNAL_FUNC (on_use_default_font_toggled), p);
+	gtk_signal_connect (GTK_OBJECT (checkbutton5), "toggled",
+			    GTK_SIGNAL_FUNC (on_use_default_attrib_toggled), p);
+	gtk_signal_connect (GTK_OBJECT (checkbutton6), "toggled",
+			    GTK_SIGNAL_FUNC (on_use_default_fore_toggled), p);
+	gtk_signal_connect (GTK_OBJECT (checkbutton7), "toggled",
+			    GTK_SIGNAL_FUNC (on_use_default_back_toggled), p);
+
+	p->widgets.font_picker = fontpicker1;
+	p->widgets.font_size_spin = spinbutton1;
+	p->widgets.hilite_item_combo = combo2;
+	p->widgets.font_bold_check = checkbutton2;
+	p->widgets.font_italics_check = checkbutton3;
+	p->widgets.font_underlined_check = checkbutton4;
+	p->widgets.fore_colorpicker = colorpicker1;
+	p->widgets.back_colorpicker = colorpicker2;
+	p->widgets.font_use_default_check = checkbutton1;
+	p->widgets.font_attrib_use_default_check = checkbutton5;
+	p->widgets.fore_color_use_default_check = checkbutton6;
+	p->widgets.back_color_use_default_check = checkbutton7;
+	p->widgets.caret_fore_color = colorpicker3;
+	p->widgets.calltip_back_color = colorpicker4;
+	p->widgets.selection_fore_color = colorpicker5;
+	p->widgets.selection_back_color = colorpicker6;
+	
+	gtk_widget_ref (fontpicker1);
+	gtk_widget_ref (combo2);
+	gtk_widget_ref (spinbutton1);
+	gtk_widget_ref (checkbutton1);
+	gtk_widget_ref (checkbutton2);
+	gtk_widget_ref (checkbutton3);
+	gtk_widget_ref (checkbutton4);
+	gtk_widget_ref (checkbutton5);
+	gtk_widget_ref (checkbutton6);
+	gtk_widget_ref (checkbutton7);
+	gtk_widget_ref (colorpicker1);
+	gtk_widget_ref (colorpicker2);
+	gtk_widget_ref (colorpicker3);
+	gtk_widget_ref (colorpicker4);
+	gtk_widget_ref (colorpicker5);
+	gtk_widget_ref (colorpicker6);
+
+	return frame;
+}
+
+static GtkWidget *
+create_preferences_page3 (Preferences * p)
+{
+	GtkWidget *frame1;
+	GtkWidget *vbox2;
+	GtkWidget *table2;
+	GtkWidget *checkbutton9;
+	GtkObject *spinbutton2_adj;
+	GtkWidget *spinbutton2;
+	GtkObject *spinbutton3_adj;
+	GtkWidget *spinbutton3;
+	GtkWidget *checkbutton10;
+	GtkWidget *checkbutton12;
+	GtkWidget *checkbutton11;
+	GtkWidget *checkbutton8;
+	GtkObject *spinbutton4_adj;
+	GtkWidget *spinbutton4;
+	GtkWidget *vseparator1;
+	GtkObject *spinbutton5_adj;
+	GtkWidget *spinbutton5;
+	GtkObject *spinbutton6_adj;
+	GtkWidget *spinbutton6;
+	GtkWidget *label6;
+	GtkWidget *label7;
+	GtkWidget *label8;
+	GtkWidget *label9;
+	GtkWidget *label10;
+	GtkWidget *checkbutton4;
+	GtkWidget *checkbutton5;
+
+	frame1 = gtk_frame_new (NULL);
+	gtk_widget_show (frame1);
+	gtk_container_set_border_width (GTK_CONTAINER (frame1), 5);
+
+	vbox2 = gtk_vbox_new (FALSE, 0);
+	gtk_widget_show (vbox2);
+	gtk_container_add (GTK_CONTAINER (frame1), vbox2);
+
+	table2 = gtk_table_new (7, 4, FALSE);
+	gtk_widget_show (table2);
+	gtk_box_pack_start (GTK_BOX (vbox2), table2, TRUE, TRUE, 0);
+	gtk_table_set_row_spacings (GTK_TABLE (table2), 2);
+	gtk_table_set_col_spacings (GTK_TABLE (table2), 5);
+	gtk_container_set_border_width (GTK_CONTAINER(table2), 5);
+
 	checkbutton8 =
 		gtk_check_button_new_with_label (_
-						 ("Disable Syntax hilighting"));
+						 ("Disable syntax highlighting"));
 	gtk_widget_show (checkbutton8);
 	gtk_table_attach (GTK_TABLE (table2), checkbutton8, 0, 1, 0, 1,
 			  (GtkAttachOptions) (GTK_FILL),
@@ -829,7 +969,7 @@ create_preferences_page2 (Preferences * p)
 
 	vseparator1 = gtk_vseparator_new ();
 	gtk_widget_show (vseparator1);
-	gtk_table_attach (GTK_TABLE (table2), vseparator1, 1, 2, 0, 5,
+	gtk_table_attach (GTK_TABLE (table2), vseparator1, 1, 2, 0, 7,
 			  (GtkAttachOptions) (0),
 			  (GtkAttachOptions) (GTK_FILL), 6, 0);
 
@@ -908,30 +1048,22 @@ create_preferences_page2 (Preferences * p)
 			  (GtkAttachOptions) (GTK_FILL),
 			  (GtkAttachOptions) (0), 5, 0);
 
+	checkbutton4 =
+		gtk_check_button_new_with_label (_
+						 ("Strip trailing spaces on file save"));
+	gtk_widget_show (checkbutton4);
+	gtk_table_attach (GTK_TABLE (table2), checkbutton4, 0, 1, 5, 6,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
 
-	gtk_signal_connect (GTK_OBJECT (combo_entry2), "changed",
-			    GTK_SIGNAL_FUNC (on_hilite_style_entry_changed), p);
-	gtk_signal_connect (GTK_OBJECT (checkbutton1), "toggled",
-			    GTK_SIGNAL_FUNC (on_use_default_font_toggled), p);
-	gtk_signal_connect (GTK_OBJECT (checkbutton5), "toggled",
-			    GTK_SIGNAL_FUNC (on_use_default_attrib_toggled), p);
-	gtk_signal_connect (GTK_OBJECT (checkbutton6), "toggled",
-			    GTK_SIGNAL_FUNC (on_use_default_fore_toggled), p);
-	gtk_signal_connect (GTK_OBJECT (checkbutton7), "toggled",
-			    GTK_SIGNAL_FUNC (on_use_default_back_toggled), p);
+	checkbutton5 =
+		gtk_check_button_new_with_label (_
+						 ("Collapse all folds on file open"));
+	gtk_widget_show (checkbutton5);
+	gtk_table_attach (GTK_TABLE (table2), checkbutton5, 0, 1, 6, 7,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
 
-	p->widgets.font_picker = fontpicker1;
-	p->widgets.font_size_spin = spinbutton1;
-	p->widgets.hilite_item_combo = combo2;
-	p->widgets.font_bold_check = checkbutton2;
-	p->widgets.font_italics_check = checkbutton3;
-	p->widgets.font_underlined_check = checkbutton4;
-	p->widgets.fore_colorpicker = colorpicker1;
-	p->widgets.back_colorpicker = colorpicker2;
-	p->widgets.font_use_default_check = checkbutton1;
-	p->widgets.font_attrib_use_default_check = checkbutton5;
-	p->widgets.fore_color_use_default_check = checkbutton6;
-	p->widgets.back_color_use_default_check = checkbutton7;
 	p->widgets.disable_hilite_check = checkbutton8;
 	p->widgets.auto_save_check = checkbutton9;
 	p->widgets.auto_indent_check = checkbutton10;
@@ -942,68 +1074,22 @@ create_preferences_page2 (Preferences * p)
 	p->widgets.autoindent_size_spin = spinbutton3;
 	p->widgets.linenum_margin_width_spin = spinbutton4;
 	p->widgets.session_timer_spin = spinbutton6;
+	
+	p->widgets.strip_spaces_check = checkbutton4;
+	p->widgets.fold_on_open_check = checkbutton5;
 
-	gtk_widget_ref (fontpicker1);
-	gtk_widget_ref (combo2);
-	gtk_widget_ref (spinbutton1);
 	gtk_widget_ref (spinbutton2);
 	gtk_widget_ref (spinbutton3);
 	gtk_widget_ref (spinbutton4);
 	gtk_widget_ref (spinbutton5);
 	gtk_widget_ref (spinbutton6);
-	gtk_widget_ref (checkbutton1);
-	gtk_widget_ref (checkbutton2);
-	gtk_widget_ref (checkbutton3);
 	gtk_widget_ref (checkbutton4);
 	gtk_widget_ref (checkbutton5);
-	gtk_widget_ref (checkbutton6);
-	gtk_widget_ref (checkbutton7);
 	gtk_widget_ref (checkbutton8);
 	gtk_widget_ref (checkbutton9);
 	gtk_widget_ref (checkbutton10);
 	gtk_widget_ref (checkbutton11);
 	gtk_widget_ref (checkbutton12);
-	gtk_widget_ref (colorpicker1);
-	gtk_widget_ref (colorpicker2);
-
-	return vbox1;
-}
-
-static GtkWidget *
-create_preferences_page3 (Preferences * p)
-{
-	GtkWidget *frame1;
-	GtkWidget *vbox2;
-	GtkWidget *checkbutton4;
-	GtkWidget *checkbutton5;
-
-	frame1 = gtk_frame_new (NULL);
-	gtk_widget_show (frame1);
-	gtk_container_set_border_width (GTK_CONTAINER (frame1), 5);
-
-	vbox2 = gtk_vbox_new (FALSE, 0);
-	gtk_widget_show (vbox2);
-	gtk_container_add (GTK_CONTAINER (frame1), vbox2);
-
-	checkbutton4 =
-		gtk_check_button_new_with_label (_
-						 ("Strip trailing spaces on file save."));
-	gtk_widget_show (checkbutton4);
-	gtk_box_pack_start (GTK_BOX (vbox2), checkbutton4, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (checkbutton4), 5);
-
-	checkbutton5 =
-		gtk_check_button_new_with_label (_
-						 ("Collapse all folds on file open."));
-	gtk_widget_show (checkbutton5);
-	gtk_box_pack_start (GTK_BOX (vbox2), checkbutton5, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (checkbutton5), 5);
-
-	p->widgets.strip_spaces_check = checkbutton4;
-	p->widgets.fold_on_open_check = checkbutton5;
-
-	gtk_widget_ref (checkbutton4);
-	gtk_widget_ref (checkbutton5);
 
 	return frame1;
 }
@@ -1136,7 +1222,7 @@ create_preferences_page5 (Preferences * p)
 	label1 =
 		gtk_label_new (_
 			       ("Enter the command line arguments for the 'indent' program."
-				"\nRead the info page for the 'indent' for more details."));
+				"\nRead the info page for 'indent' for more details."));
 	gtk_widget_show (label1);
 	gtk_box_pack_start (GTK_BOX (vbox2), label1, FALSE, FALSE, 5);
 	gtk_label_set_justify (GTK_LABEL (label1), GTK_JUSTIFY_LEFT);
@@ -1179,8 +1265,6 @@ create_preferences_page6 (Preferences * p)
 	GtkWidget *spinbutton1;
 	GtkObject *spinbutton2_adj;
 	GtkWidget *spinbutton2;
-	GtkWidget *label4;
-	GtkWidget *label3;
 	GtkWidget *label1;
 	GtkWidget *label2;
 	GtkWidget *frame3;
@@ -1211,7 +1295,7 @@ create_preferences_page6 (Preferences * p)
 	gtk_box_pack_start (GTK_BOX (vbox1), frame2, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (frame2), 5);
 
-	table1 = gtk_table_new (3, 3, FALSE);
+	table1 = gtk_table_new (2, 3, FALSE);
 	gtk_widget_show (table1);
 	gtk_container_add (GTK_CONTAINER (frame2), table1);
 	gtk_table_set_row_spacings (GTK_TABLE (table1), 5);
@@ -1229,7 +1313,7 @@ create_preferences_page6 (Preferences * p)
 	spinbutton1 =
 		gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton1_adj), 1, 0);
 	gtk_widget_show (spinbutton1);
-	gtk_table_attach (GTK_TABLE (table1), spinbutton1, 1, 2, 1, 2,
+	gtk_table_attach (GTK_TABLE (table1), spinbutton1, 0, 1, 1, 2,
 			  (GtkAttachOptions) (0), (GtkAttachOptions) (0), 0,
 			  0);
 	gtk_widget_set_usize (spinbutton1, 60, -2);
@@ -1239,36 +1323,25 @@ create_preferences_page6 (Preferences * p)
 	spinbutton2 =
 		gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton2_adj), 1, 0);
 	gtk_widget_show (spinbutton2);
-	gtk_table_attach (GTK_TABLE (table1), spinbutton2, 1, 2, 2, 3,
+	gtk_table_attach (GTK_TABLE (table1), spinbutton2, 0, 1, 2, 3,
 			  (GtkAttachOptions) (0),
 			  (GtkAttachOptions) (0), 0, 0);
 	gtk_widget_set_usize (spinbutton2, 60, -2);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton2), TRUE);
-
-	label4 = gtk_label_new (_("characters"));
-	gtk_widget_show (label4);
-	gtk_table_attach (GTK_TABLE (table1), label4, 2, 3, 2, 3,
-			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-			  (GtkAttachOptions) (0), 0, 0);
-
-	label3 = gtk_label_new (_("characters"));
-	gtk_widget_show (label3);
-	gtk_table_attach (GTK_TABLE (table1), label3, 2, 3, 1, 2,
-			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-			  (GtkAttachOptions) (0), 0, 0);
-
-	label1 = gtk_label_new (_("Show first"));
+		
+	label1 = gtk_label_new (_("Number of first characters to show"));
 	gtk_widget_show (label1);
-	gtk_table_attach (GTK_TABLE (table1), label1, 0, 1, 1, 2,
+	gtk_table_attach (GTK_TABLE (table1), label1, 1, 2, 1, 2,
 			  (GtkAttachOptions) (0),
 			  (GtkAttachOptions) (0), 5, 0);
-	gtk_label_set_justify (GTK_LABEL (label1), GTK_JUSTIFY_RIGHT);
+	gtk_label_set_justify (GTK_LABEL (label1), GTK_JUSTIFY_LEFT);
 
-	label2 = gtk_label_new (_("Show last"));
+	label2 = gtk_label_new (_("Number of last characters to show"));
 	gtk_widget_show (label2);
-	gtk_table_attach (GTK_TABLE (table1), label2, 0, 1, 2, 3,
+	gtk_table_attach (GTK_TABLE (table1), label2, 1, 2, 2, 3,
 			  (GtkAttachOptions) (0),
 			  (GtkAttachOptions) (0), 5, 0);
+	gtk_label_set_justify (GTK_LABEL (label2), GTK_JUSTIFY_LEFT);
 
 	frame3 = gtk_frame_new (_(" Notebook tags position "));
 	gtk_widget_show (frame3);
@@ -1355,6 +1428,8 @@ create_preferences_page6 (Preferences * p)
 	gtk_widget_ref (spinbutton2);
 	p->widgets.mesg_last_spin = spinbutton2;
 
+	on_trunc_mesg_check_clicked (GTK_BUTTON (p->widgets.truncat_mesg_check), p);
+	
 	p->widgets.tag_pos_radio[0] = radiobutton1;
 	p->widgets.tag_pos_radio[1] = radiobutton2;
 	p->widgets.tag_pos_radio[2] = radiobutton3;
@@ -1383,7 +1458,7 @@ IntFromHexDigit (const gchar ch)
 		return 0;
 }
 
-static void
+void
 ColorFromString (const gchar * val, guint8 * r, guint8 * g, guint8 * b)
 {
 	*r = IntFromHexDigit (val[1]) * 16 + IntFromHexDigit (val[2]);
@@ -1407,7 +1482,7 @@ StringFromColor (guint8 r, guint8 g, guint8 b)
 	return g_strdup (str);
 }
 
-void
+static void
 on_preferences_ok_clicked (GtkButton * button, gpointer user_data)
 {
 	Preferences *pr = (Preferences *) user_data;
@@ -1418,7 +1493,7 @@ on_preferences_ok_clicked (GtkButton * button, gpointer user_data)
 	}
 }
 
-gboolean
+static gboolean
 on_preferences_delete_event (GtkWidget * w, GdkEvent * event,
 			     gpointer user_data)
 {
@@ -1430,11 +1505,12 @@ on_preferences_delete_event (GtkWidget * w, GdkEvent * event,
 	return TRUE;
 }
 
-void
+static void
 on_preferences_apply_clicked (GtkButton * button, gpointer user_data)
 {
 	gint i;
 	gchar *str;
+	gint8 r, g, b, a;
 
 	Preferences *pr = (Preferences *) user_data;
 
@@ -1518,7 +1594,44 @@ on_preferences_apply_clicked (GtkButton * button, gpointer user_data)
 		if (str)
 			g_free (str);
 	}
+	gnome_color_picker_get_i8 (GNOME_COLOR_PICKER
+				   (pr->widgets.caret_fore_color), &r,
+				   &g, &b, &a);
+	str = StringFromColor (r, g, b);
+	if(str)
+	{
+		preferences_set(pr, CARET_FORE_COLOR, str);
+		g_free (str);
+	}
+	gnome_color_picker_get_i8 (GNOME_COLOR_PICKER
+				   (pr->widgets.calltip_back_color), &r,
+				   &g, &b, &a);
+	str = StringFromColor (r, g, b);
+	if(str)
+	{
+		preferences_set(pr, CALLTIP_BACK_COLOR, str);
+		g_free (str);
+	}
+	gnome_color_picker_get_i8 (GNOME_COLOR_PICKER
+				   (pr->widgets.selection_fore_color), &r,
+				   &g, &b, &a);
+	str = StringFromColor (r, g, b);
+	if(str)
+	{
+		preferences_set(pr, SELECTION_FORE_COLOR, str);
+		g_free (str);
+	}
+	gnome_color_picker_get_i8 (GNOME_COLOR_PICKER
+				   (pr->widgets.selection_back_color), &r,
+				   &g, &b, &a);
+	str = StringFromColor (r, g, b);
+	if(str)
+	{
+		preferences_set(pr, SELECTION_BACK_COLOR, str);
+		g_free (str);
+	}
 
+/* page 3 */
 	preferences_set_int (pr, DISABLE_SYNTAX_HILIGHTING,
 			     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
 							   (pr->widgets.
@@ -1561,7 +1674,6 @@ on_preferences_apply_clicked (GtkButton * button, gpointer user_data)
 							       (pr->widgets.
 								session_timer_spin)));
 
-/* page 3 */
 	preferences_set_int (pr, STRIP_TRAILING_SPACES,
 			     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
 							   (pr->widgets.strip_spaces_check)));
@@ -1650,7 +1762,7 @@ on_preferences_apply_clicked (GtkButton * button, gpointer user_data)
 /* preferences_save_yourself(pr); */
 }
 
-void
+static void
 on_preferences_cancel_clicked (GtkButton * button, gpointer user_data)
 {
 	Preferences *pr = (Preferences *) user_data;
