@@ -17,7 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* Most of the codes stollen from glade and modified */
+/* Most of the code stolen from Glade and modified */
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -134,7 +134,7 @@ source_write_no_modify_warning (ProjectDBase * data, FILE * fp)
 	fprintf (fp,
 	"## Created by Anjuta - will be overwritten\n"
 	"## If you don't want it to overwrite it,\n"
-	"## \tPlease disable it in the Anjtua Project configuration\n\n");
+	"## \tPlease disable it in the Anjuta project configuration\n\n");
 	return TRUE;
 }
 
@@ -159,6 +159,12 @@ source_write_autogen_sh (ProjectDBase * data)
 	case PROJECT_TYPE_GTK:
 		srcbuffer = g_strconcat (app->dirs->data, "/autogen.sh.gtk", NULL);
 		break;
+	case PROJECT_TYPE_GTKMM:
+		srcbuffer = g_strconcat (app->dirs->data, "/autogen.sh.gtkmm", NULL);
+		break;
+	case PROJECT_TYPE_GNOMEMM:
+		srcbuffer = g_strconcat (app->dirs->data, "/autogen.sh.gnomemm", NULL);
+		break;
 	case PROJECT_TYPE_GNOME:
 	case PROJECT_TYPE_BONOBO:
 		srcbuffer = g_strconcat (app->dirs->data, "/autogen.sh.gnome", NULL);
@@ -200,14 +206,17 @@ source_write_configure_in (ProjectDBase * data)
 {
 	FILE *fp;
 	gchar *filename, *actual_file, *target, *version;
-	gint type, i;
+	gint type, lang_type, i;
 	GList *list, *node;
 
 	g_return_val_if_fail (data != NULL, FALSE);
 
 	type = project_dbase_get_project_type(data);
 	g_return_val_if_fail (type < PROJECT_TYPE_END_MARK, FALSE);
-
+	
+	lang_type = project_dbase_get_language (data);
+	g_return_val_if_fail (lang_type < 	PROJECT_PROGRAMMING_LANGUAGE_END_MARK, FALSE);
+	
 	filename = get_a_tmp_file();
 	actual_file = g_strconcat (data->top_proj_dir, "/configure.in", NULL);
 
@@ -228,31 +237,50 @@ source_write_configure_in (ProjectDBase * data)
 	 * using a file unique to the project. */
 	fprintf (fp,
 		 "dnl Process this file with autoconf to produce a configure script.\n"
-		"dnl Created by Anjuta - will be overwritten\n"
-		"dnl If you don't want it to overwrite it,\n"
-		"dnl \tPlease disable it in the Anjtua Project configuration\n"
+		 "dnl Created by Anjuta - will be overwritten\n"
+		 "dnl If you don't want it to overwrite it,\n"
+		 "dnl \tPlease disable it in the Anjuta project configuration\n"
 		 "\n"
 		 "AC_INIT(configure.in)\n"
 		 "AM_INIT_AUTOMAKE(%s, %s)\n"
 		 "AM_CONFIG_HEADER(config.h)\n"
 		 "\n"
-		 "AC_ISC_POSIX\n"
-		 "AC_PROG_CC\n"
-		 "AC_PROG_CXX\n"
-		 "AM_PROG_CC_STDC\n"
-		 "AC_HEADER_STDC\n", target, version);
+		 "AC_ISC_POSIX\n", target, version);
+	switch (lang_type)
+	{
+		case PROJECT_PROGRAMMING_LANGUAGE_C:
+			fprintf (fp, "AC_PROG_CC\n");
+			break;
+		case PROJECT_PROGRAMMING_LANGUAGE_CPP:
+			fprintf (fp, "AC_PROG_CXX\n");
+			break;
+		case PROJECT_PROGRAMMING_LANGUAGE_C_CPP:
+			fprintf (fp, "AC_PROG_CC\n");
+			fprintf (fp, "AC_PROG_CXX\n");
+			break;
+		default:
+			fprintf (fp, "AC_PROG_CC\n");
+			break;
+	}
+	fprintf(fp, "AM_PROG_CC_STDC\n"
+		 "AC_HEADER_STDC\n");
 	switch (type)
 	{
 	case PROJECT_TYPE_BONOBO:
 	case PROJECT_TYPE_GNOME:
+	case PROJECT_TYPE_GNOMEMM:
 		fprintf (fp,
 			 "\n"
-			 "dnl Pick up the Gnome macros.\n"
+			 "dnl Pick up the GNOME macros.\n"
 			 "AM_ACLOCAL_INCLUDE(macros)\n"
 			 "\n"
-			 "dnl Gnome macros.\n"
+			 "dnl GNOME macros.\n"
 			 "GNOME_INIT\n"
 			 "GNOME_COMPILE_WARNINGS\nGNOME_X_CHECKS\n");
+		if (type == PROJECT_TYPE_GNOMEMM)
+		{
+				/* Maybe there will be some Gnome-- checks in the future*/
+		}
 		break;
 	case PROJECT_TYPE_GTK:
 		fprintf (fp,
@@ -260,6 +288,12 @@ source_write_configure_in (ProjectDBase * data)
 			 "AM_PATH_GTK(1.2.0, ,\n"
 			 "            AC_MSG_ERROR(Cannot find GTK: Is gtk-config in path?))\n");
 		break;
+	case PROJECT_TYPE_GTKMM:
+		fprintf(fp, 
+			"\n"
+			"AM_PATH_GTKMM(1.2.0, ,\n"
+			"								AC_MSG_ERROR(Cannot find GTK--: Is gtkmm-config in path?))\n");
+		break;
 	case PROJECT_TYPE_GENERIC:
 		break;
 	}
@@ -275,10 +309,10 @@ source_write_configure_in (ProjectDBase * data)
 		GList *files, *node;
 		fprintf (fp,
 			 "\n"
-			 "dnl Add the languages which your application supports here.\n"
+			 "dnl Languages which your application supports\n"
 			 "ALL_LINGUAS=\"");
 		files = project_dbase_get_module_files (data, MODULE_PO);
-		node = files;
+		node = glist_strings_sort (files);
 		while (node)
 		{
 			if (node->data)
@@ -288,10 +322,12 @@ source_write_configure_in (ProjectDBase * data)
 				ext = get_file_extension (lang);
 				if (ext)
 					*(--ext) = '\0';
-				fprintf(fp, " %s", lang);
+				fprintf(fp, "%s", lang);
 				g_free (lang);
 			}
 			node = g_list_next (node);
+			if (node)
+				fprintf(fp, " ");
 		}
 		fprintf (fp,
 			 "\"\n" "AM_GNU_GETTEXT\n" "\n");
@@ -308,53 +344,95 @@ source_write_configure_in (ProjectDBase * data)
 	 * pixmaps. */
 	fprintf (fp,
 		 "\n"
-		 "dnl Set PACKAGE_SOURCE_DIR in config.h.\n"
+		 "dnl Set PACKAGE SOURCE DIR in config.h.\n"
 		 "packagesrcdir=`cd $srcdir && pwd`\n"
-		 "AC_DEFINE_UNQUOTED(PACKAGE_SOURCE_DIR, \"${packagesrcdir}\")\n"
 		 "\n");
-	/* Define PACKAGE_DATA_DIR in config.h so the app can find installed pixmaps.
+	
+	/* Define PACKAGE_DATA and PACKAGE_DOC DIR in config.h so the app can find installed pixmaps.
 	 */
 	fprintf (fp,
-		 "dnl Set PACKAGE_DATA_DIR in config.h.\n"
-		 "if test \"x${datadir}\" = 'x${prefix}/share'; then\n"
-		 "  if test \"x${prefix}\" = \"xNONE\"; then\n"
-		 "    AC_DEFINE_UNQUOTED(PACKAGE_DATA_DIR, \"${ac_default_prefix}/share/${PACKAGE}\")\n"
-		 "  else\n"
-		 "    AC_DEFINE_UNQUOTED(PACKAGE_DATA_DIR, \"${prefix}/share/${PACKAGE}\")\n"
-		 "  fi\n"
+		 "dnl Set PACKAGE PREFIX\n"
+		 "if test \"x${prefix}\" = \"xNONE\"; then\n"
+		 "  packageprefix=${ac_default_prefix}\n"
 		 "else\n"
-		 "  AC_DEFINE_UNQUOTED(PACKAGE_DATA_DIR, \"${datadir}/${PACKAGE}\")\n"
-		 "fi\n" "\n");
-	/*
-	 * Subst PACKAGE_PIXMAPS_DIR, PACKAGE_HELP_DIR, PACKAGE_MENU_DIR, 
-	 * so the Makefile.am knows where to install the pixmaps, help htmls,
-	 * and menu desktop entry respectively.
+		 "  packageprefix=${prefix}\n"
+		 "fi\n\n");
+	fprintf (fp,
+		 "dnl Set PACKAGE DATA & DOC DIR\n"
+		 "packagedatadir=share/${PACKAGE}\n"
+		 "packagedocdir=doc/${PACKAGE}\n"
+		 "\n");
+	
+	/* Define PIXMAPS, HELP, MENU DIR so that the app can find installed pixmaps.
 	 */
-	if (type == PROJECT_TYPE_GNOME || type == PROJECT_TYPE_BONOBO)
+	if (type == PROJECT_TYPE_GENERIC || type == PROJECT_TYPE_GTK)
 	{
 		fprintf (fp,
-			 "dnl Subst PACKAGE_PIXMAPS_DIR.\n"
-			 "PACKAGE_PIXMAPS_DIR=\"`gnome-config --datadir`/pixmaps/${PACKAGE}\"\n"
-			 "AC_SUBST(PACKAGE_PIXMAPS_DIR)\n\n");
-		fprintf (fp,
-			 "dnl Subst PACKAGE_HELP_DIR.\n"
-			 "PACKAGE_HELP_DIR=\"`gnome-config --datadir`/gnome/help/${PACKAGE}\"\n"
-			 "AC_SUBST(PACKAGE_HELP_DIR)\n\n");
-		fprintf (fp,
-			 "dnl Subst PACKAGE_MENU_DIR.\n"
-			 "PACKAGE_MENU_DIR=\"`gnome-config --datadir`/gnome/apps\"\n"
-			 "AC_SUBST(PACKAGE_MENU_DIR)\n\n");
+			 "dnl Set PACKAGE DIRS in config.h.\n"
+			 "packagepixmapsdir=${packagedatadir}/pixmaps\n"
+			 "packagehelpdir=${packagedatadir}/help\n"
+			 "packagemenudir=${packagedatadir}\n");
 	}
+	else
+	{
+		fprintf (fp,
+			 "dnl Set PACKAGE DIRs in config.h.\n"
+			 "packagepixmapsdir=share/pixmaps/${PACKAGE}\n"
+			 "packagehelpdir=share/gnome/help/${PACKAGE}\n"
+			 "packagemenudir=share/gnome/apps\n");
+	}
+	fprintf (fp, "\n");
+	/* Substitute Directories in Makefiles */
+	fprintf (fp,
+		 "dnl Subst PACKAGE_DATA_DIR.\n"
+		 "NO_PREFIX_PACKAGE_DATA_DIR=\"${packagedatadir}\"\n"
+		 "AC_SUBST(NO_PREFIX_PACKAGE_DATA_DIR)\n"
+		 "PACKAGE_DATA_DIR=\"${packageprefix}/${packagedatadir}\"\n"
+		 "AC_SUBST(PACKAGE_DATA_DIR)\n"
+		 "\n"
+		 "dnl Subst PACKAGE_DOC_DIR.\n"
+		 "NO_PREFIX_PACKAGE_DOC_DIR=\"${packagedocdir}\"\n"
+		 "AC_SUBST(NO_PREFIX_PACKAGE_DOC_DIR)\n"
+		 "PACKAGE_DOC_DIR=\"${packageprefix}/${packagedocdir}\"\n"
+		 "AC_SUBST(PACKAGE_DOC_DIR)\n"
+		 "\n"
+		 "dnl Subst PACKAGE_PIXMAPS_DIR.\n"
+		 "NO_PREFIX_PACKAGE_PIXMAPS_DIR=\"${packagepixmapsdir}\"\n"
+		 "AC_SUBST(NO_PREFIX_PACKAGE_PIXMAPS_DIR)\n"
+		 "PACKAGE_PIXMAPS_DIR=\"${packageprefix}/${packagepixmapsdir}\"\n"
+		 "AC_SUBST(PACKAGE_PIXMAPS_DIR)\n"
+		 "\n"
+		 "dnl Subst PACKAGE_HELP_DIR.\n"
+		 "NO_PREFIX_PACKAGE_HELP_DIR=\"${packagehelpdir}\"\n"
+		 "AC_SUBST(NO_PREFIX_PACKAGE_HELP_DIR)\n"
+		 "PACKAGE_HELP_DIR=\"${packageprefix}/${packagehelpdir}\"\n"
+		 "AC_SUBST(PACKAGE_HELP_DIR)\n"
+		 "\n"
+		 "dnl Subst PACKAGE_MENU_DIR.\n"
+		 "NO_PREFIX_PACKAGE_MENU_DIR=\"${packagemenudir}\"\n"
+		 "AC_SUBST(NO_PREFIX_PACKAGE_MENU_DIR)\n"
+		 "PACKAGE_MENU_DIR=\"${packageprefix}/${packagemenudir}\"\n"
+		 "AC_SUBST(PACKAGE_MENU_DIR)\n"
+		 "\n");
+	/* Define derectories in config.h file */
+	fprintf (fp,
+		 "AC_DEFINE_UNQUOTED(PACKAGE_DATA_DIR, \"${packageprefix}/${packagedatadir}\")\n"
+		 "AC_DEFINE_UNQUOTED(PACKAGE_DOC_DIR, \"${packageprefix}/${packagedocdir}\")\n"
+		 "AC_DEFINE_UNQUOTED(PACKAGE_PIXMAPS_DIR, \"${packageprefix}/${packagepixmapsdir}\")\n"
+		 "AC_DEFINE_UNQUOTED(PACKAGE_HELP_DIR, \"${packageprefix}/${packagehelpdir}\")\n"
+		 "AC_DEFINE_UNQUOTED(PACKAGE_MENU_DIR, \"${packageprefix}/${packagemenudir}\")\n"
+		 "AC_DEFINE_UNQUOTED(PACKAGE_SOURCE_DIR, \"${packagesrcdir}\")\n");
+	fprintf (fp, "\n");
 
 	fprintf (fp, "AC_OUTPUT([\n" "Makefile\n");
-
 	if (prop_get_int (data->props, "project.has.gettext", 1))
 	{
 		fprintf (fp,
 			 "intl/Makefile\n"
 			 "po/Makefile.in\n");
 	}
-	if (type == PROJECT_TYPE_GNOME || type == PROJECT_TYPE_BONOBO)
+	if (type == PROJECT_TYPE_GNOME || type == PROJECT_TYPE_BONOBO
+			|| type == PROJECT_TYPE_GNOMEMM)
 	{
 		fprintf (fp, "macros/Makefile\n");
 	}
@@ -410,7 +488,8 @@ source_write_configure_in (ProjectDBase * data)
 	}
 	glist_strings_free (list);
 
-	if (type == PROJECT_TYPE_GNOME || type == PROJECT_TYPE_BONOBO)
+	if (type == PROJECT_TYPE_GNOME || type == PROJECT_TYPE_BONOBO
+			|| type == PROJECT_TYPE_GNOMEMM)
 	{
 		fprintf (fp, "%s.desktop\n", target);
 	}
@@ -454,7 +533,9 @@ source_write_toplevel_makefile_am (ProjectDBase * data)
 
 	if (prop_get_int (data->props, "project.has.gettext", 1))
 		fprintf (fp, " intl po");
-	if (type == PROJECT_TYPE_GNOME || type == PROJECT_TYPE_BONOBO)
+	if (type == PROJECT_TYPE_GNOME
+		|| type == PROJECT_TYPE_GNOMEMM
+		|| type == PROJECT_TYPE_BONOBO)
 		fprintf (fp, " macros");
 
 	if (data->project_config->extra_modules_before)
@@ -500,13 +581,13 @@ source_write_toplevel_makefile_am (ProjectDBase * data)
 	fprintf (fp,
 		"\n\nEXTRA_DIST = %s $(%sdoc_DATA)\n\n",
 		extract_filename (data->proj_filename), target);
-	if(type == PROJECT_TYPE_GNOME  || type == PROJECT_TYPE_BONOBO)
+	if(type != PROJECT_TYPE_GENERIC  && type != PROJECT_TYPE_GTK)
 	{
 		gchar *group;
 		
 		group = prop_get (data->props, "project.menu.group");
 		if (!group) group = g_strdup ("Applications");
-		fprintf (fp, "gnomemenudir = @PACKAGE_MENU_DIR@/%s\n", group);
+		fprintf (fp, "gnomemenudir = $(prefix)/@NO_PREFIX_PACKAGE_MENU_DIR@/%s\n", group);
 		fprintf (fp, "gnomemenu_DATA = %s.desktop\n\n", target);
 		g_free (group);
 	}
@@ -516,6 +597,14 @@ source_write_toplevel_makefile_am (ProjectDBase * data)
 		fprintf (fp, data->project_config->makefile_am);
 		fprintf (fp, "\n");
 	}
+	fprintf (fp, "# Copy all the spec files. Of cource, only one is actually used.\n");
+	fprintf (fp, "dist-hook:\n"
+		  "\tfor specfile in *.spec; do \\\n"
+		  "\t\tif test -f $$specfile; then \\\n"
+		  "\t\t\tcp -p $$specfile $(distdir); \\\n"
+		  "\t\tfi \\\n"
+		  "\tdone\n"
+		  "\n");
 	fclose (fp);
 	if (move_file_if_not_same(filename, actual_file) == FALSE)
 		anjuta_system_error (errno, _("Couldn't create file: %s."), actual_file);
@@ -529,6 +618,7 @@ static gboolean
 source_write_macros_files (ProjectDBase * data)
 {
 	static const gchar *files[] = {
+		"ChangeLog",
 		"Makefile.am",
 		"aclocal-include.m4",
 		"autogen.sh",
@@ -537,6 +627,7 @@ source_write_macros_files (ProjectDBase * data)
 		"gnome-bonobo-check.m4",
 		"gnome-common.m4",
 		"gnome-fileutils.m4",
+		"gnome-gettext.m4",
 		"gnome-ghttp-check.m4",
 		"gnome-gnorba-check.m4",
 		"gnome-guile-checks.m4",
@@ -696,6 +787,15 @@ source_write_executable_source_files (ProjectDBase * data)
 	{
 		fprintf (fp, " \\\n\t`gtk-config --cflags`");
 	}
+	if (type == PROJECT_TYPE_GTKMM)
+	{
+		fprintf(fp, "\\\n\t`gtkmm-config --cflags`");
+	}
+	if (type == PROJECT_TYPE_GNOMEMM)
+	{
+		fprintf(fp, "\\\n\t`$(GNOME_CONFIG) --cflags gnomemm`");
+		/* fprintf(fp, "\\\n\t`gnome-config --cflags gnomemm`"); */
+	}
 	compiler_options_set_prjcflags_in_file (app->compiler_options, fp);
 	fprintf (fp, "\n\n");
 
@@ -860,14 +960,7 @@ source_write_pixmap_files (ProjectDBase * data)
 	target =
 		prop_get (data->props, "project.source.target");
 	g_strdelimit (target, "-", '_');
-	if (type == PROJECT_TYPE_GNOME)
-	{
-		fprintf (fp, "%s_pixmapsdir = @PACKAGE_PIXMAPS_DIR@\n\n", target);
-	}
-	else
-	{
-		fprintf (fp, "%s_pixmapsdir = ${pkgdatadir}/pixmaps\n\n", target);
-	}
+	fprintf (fp, "%s_pixmapsdir = $(prefix)/@NO_PREFIX_PACKAGE_PIXMAPS_DIR@\n\n", target);
 	
 	fprintf (fp, "%s_pixmaps_DATA = \\\n", target);
 	source_write_module_file_list (data, fp, TRUE, NULL, MODULE_PIXMAP);
@@ -919,14 +1012,7 @@ source_write_help_files (ProjectDBase * data)
 	target =
 		prop_get (data->props, "project.source.target");
 	g_strdelimit (target, "-", '_');
-	if (type == PROJECT_TYPE_GNOME)
-	{
-		fprintf (fp, "%s_helpdir = @PACKAGE_HELP_DIR@/C\n\n", target);
-	}
-	else
-	{
-		fprintf (fp, "%s_helpdir = ${pkgdatadir}/help/C\n\n", target);
-	}
+	fprintf (fp, "%s_helpdir = $(prefix)/@NO_PREFIX_PACKAGE_HELP_DIR@/C\n\n", target);
 	fprintf (fp, "%s_help_DATA = \\\n", target);
 	source_write_module_file_list (data, fp, TRUE, NULL, MODULE_HELP);
 
@@ -974,7 +1060,7 @@ source_write_doc_files (ProjectDBase * data)
 	target =
 		prop_get (data->props, "project.source.target");
 	g_strdelimit (target, "-", '_');
-	fprintf (fp, "%s_docdir = ${prefix}/doc/%s\n\n", target, target);
+	fprintf (fp, "%s_docdir = $(prefix)/@NO_PREFIX_PACKAGE_DOC_DIR@\n\n", target);
 	fprintf (fp, "%s_doc_DATA = \\\n", target);
 	source_write_module_file_list (data, fp, TRUE, NULL, MODULE_DOC);
 
@@ -1022,7 +1108,7 @@ source_write_data_files (ProjectDBase * data)
 	target =
 		prop_get (data->props, "project.source.target");
 	g_strdelimit (target, "-", '_');
-	fprintf (fp, "%s_datadir = ${pkgdatadir}\n\n", target);
+	fprintf (fp, "%s_datadir = $(prefix)/@NO_PREFIX_PACKAGE_DATA_DIR@\n\n", target);
 	fprintf (fp, "%s_data_DATA = \\\n", target);
 	source_write_module_file_list (data, fp, TRUE, NULL, MODULE_DATA);
 
@@ -1071,7 +1157,11 @@ source_write_acconfig_h (ProjectDBase * data)
 		 "#undef HAVE_STPCPY\n"
 		 "#undef HAVE_LIBSM\n"
 		 "#undef PACKAGE_LOCALE_DIR\n"
+		 "#undef PACKAGE_DOC_DIR\n"
 		 "#undef PACKAGE_DATA_DIR\n"
+		 "#undef PACKAGE_PIXMAPS_DIR\n"
+		 "#undef PACKAGE_HELP_DIR\n"
+		 "#undef PACKAGE_MENU_DIR\n"
 		 "#undef PACKAGE_SOURCE_DIR\n");
 	fclose (fp);
 	g_free (filename);
@@ -1343,12 +1433,13 @@ source_write_build_files (ProjectDBase * data)
 		case PROJECT_TYPE_GENERIC:
 			break;
 		case PROJECT_TYPE_GTK:
-			ret = source_write_glade_file (data);
+		case PROJECT_TYPE_GTKMM:
+		ret = source_write_glade_file (data);
 			if (!ret) return FALSE;
-
 			break;
 		case PROJECT_TYPE_GNOME:
 		case PROJECT_TYPE_BONOBO:
+		case PROJECT_TYPE_GNOMEMM:
 			ret = source_write_desktop_entry (data);
 			if (!ret) return FALSE;
 			ret = source_write_glade_file (data);
