@@ -29,7 +29,7 @@
 #include "text_editor_cbs.h"
 #include "text_editor_gui.h"
 #include "mainmenu_callbacks.h"
-#include "support.h"
+#include "resources.h"
 #include "Scintilla.h"
 
 void
