@@ -49,6 +49,7 @@ enum _FileExtType
 	FILE_TYPE_PERL,
 	FILE_TYPE_SH,
 	FILE_TYPE_PYTHON,
+	FILE_TYPE_RUBY,
 	FILE_TYPE_PROPERTIES,
 	FILE_TYPE_PROJECT,
 	FILE_TYPE_BATCH,
@@ -98,7 +99,7 @@ gboolean parse_error_line(gchar *line, gchar **filename, int *lineno);
 /*  Functions that do not dynamic allocate memory. Return value should not be g_freed */
 /***********************************************************************************/
 
-#define string_free(str) if (str) g_free(str);
+void string_free(gchar* str);
 
 /* Get a fixed font */
 GdkFont* get_fixed_font (void);
@@ -180,12 +181,13 @@ void string_assign (gchar** string, gchar* value);
 /* Used as the callback for scandir() */
 int select_only_file (const struct dirent *e);
 
-/************************************************/
-/*  Functions that operates on list of strings. */
-/************************************************/
+/***********************************************/
+/*  Functions that operate on list of strings. */
+/***********************************************/
 void glist_strings_free(GList* list);
 void glist_strings_prefix (GList * list, gchar *prefix);
 void glist_strings_sufix (GList * list, gchar *sufix);
+GList* glist_strings_sort (GList * list);
 
 /**********************************************************/
 /* Both the returned glist and the data should be g_freed */
@@ -193,6 +195,7 @@ void glist_strings_sufix (GList * list, gchar *sufix);
 GList* glist_from_data(guint props, gchar* id);
 GList* glist_from_string(gchar* id);
 GList* glist_strings_dup (GList * list);
+
 /* Returns the alphabatically sorted list for files in dir */
 /* select is the func that approves (returning 1)each file */
 GList* scan_files_in_dir (const char *dir, int (*select)(const struct dirent *));
@@ -204,4 +207,11 @@ GList* scan_files_in_dir (const char *dir, int (*select)(const struct dirent *))
 /*******************************************************************/
 GList* remove_blank_lines(GList* lines); 
 
+/* Create a new hbox with an image and a label packed into it
+        * and return the box. */
+GtkWidget*
+create_xpm_label_box( GtkWidget *parent,
+                                 gchar     *xpm_filename, gboolean gnome_pixmap,
+                                 gchar     *label_text );
+
 #endif
